@@ -1,6 +1,6 @@
 package Gtk2::Ex::HyperTextBuffer;
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 
 use strict;
 use Gtk2;
@@ -217,6 +217,15 @@ sub _insert_blocks {
 				$self->insert_image_from_file(%$meta);
 				next;
 			}
+			elsif ($type eq 'checkbox') {
+				my $icon = 
+					($$meta{state} == 1) ? 'checked-box'  :
+					($$meta{state} == 2) ? 'xchecked-box' : 'unchecked-box' ;
+				$$meta{icon} = $icon;
+				$$meta{type} = 'checkbox';
+				$self->insert_image_from_file(%$meta);
+				next;
+			}
 			elsif ($type eq 'link') {
 				my $bit = (@$_ == 3 and $$_[2] eq $$meta{to});
 				$tag = $self->create_link_tag($bit ? undef : $$meta{to});
@@ -258,20 +267,29 @@ Use C<insert_blocks()> if you want this action to be un-doable.
 
 sub insert_image_from_file {
 	my ($self, %param) = @_;
-	die "BUG: image without 'file' attribute" unless length $param{file};
+	die "BUG: image without 'file' attribute"
+		unless length $param{file} or length $param{icon};
 
 	my $pixbuf = undef;
-	my ($w, $h) = @param{'width', 'height'};
-	eval {
-		$pixbuf = ($w || $h)
-			? Gtk2::Gdk::Pixbuf->new_from_file_at_size(
-				$param{file}, $w || -1, $h || -1 )
-			: Gtk2::Gdk::Pixbuf->new_from_file(
-				$param{file} ) ;
-	} if -f $param{file} and -r _ ;
-	$pixbuf ||= Gtk2::Image->new->render_icon(
-			'gtk-missing-image', 'dialog' )->copy;
-	die "Could not insert image: $param{file}\n" unless $pixbuf;
+	if ($param{file}) {
+		my ($w, $h) = @param{'width', 'height'};
+		eval {
+			$pixbuf = ($w || $h)
+				? Gtk2::Gdk::Pixbuf->new_from_file_at_size(
+					$param{file}, $w || -1, $h || -1 )
+				: Gtk2::Gdk::Pixbuf->new_from_file(
+					$param{file} ) ;
+		} if -f $param{file} and -r _ ;
+		$pixbuf ||= Gtk2::Image->new->render_icon(
+				'gtk-missing-image', 'dialog' )->copy;
+		die "Could not insert image: $param{file}\n" unless $pixbuf;
+	}
+	elsif ($param{icon}) {
+		$pixbuf ||= Gtk2::Image->new->render_icon(
+				$param{icon}, 'menu' )->copy;
+		die "Could not insert icon: $param{icon}\n" unless $pixbuf;
+	}
+	else { die 'BUG' }
 	
 	$pixbuf->{image_data} = \%param;
 	my $iter ||= $self->get_iter_at_mark( $self->get_insert );
@@ -325,7 +343,9 @@ sub get_parse_tree {
 				my $pixbuf = $image->get_pixbuf;
 				if ($pixbuf) {
 					my $meta = $pixbuf->{image_data};
-					push @{$stack[-1]}, ['image', $meta];
+					my $node = ($$meta{type} and $$meta{type} eq 'checkbox')
+						? 'checkbox' : 'image' ;
+					push @{$stack[-1]}, [$node, $meta];
 				}
 				$image->forward_char;
 			}
@@ -396,7 +416,7 @@ sub get_parse_tree {
 	# Filter out empty tags
 	@$root = grep {
 		defined($_) and
-		(ref($_) and ($$_[0] ne 'image')) 
+		(ref($_) and ($$_[0] ne 'image') and ($$_[0] ne 'checkbox')) 
 			? (@$_ > 2)
 			: length($_)
 	} @$root;
@@ -572,6 +592,7 @@ sub set_edit_mode_tags {
 	my $table = $self->get_tag_table;
 	$self->{edit_mode_tags} =
 		[ map { ref($_) ? $_ : $table->lookup($_) } @_ ];
+	$$self{_edit_mode_string} = "@{$self->{edit_mode_tags}}";
 	$self->signal_emit('edit_mode_changed');
 }
 
@@ -587,13 +608,14 @@ sub set_edit_mode_from_cursor {
 	my $iter = $self->get_iter_at_mark( $self->get_insert );
 	$self->{edit_mode_tags} = [$self->_get_open_tags($iter)];
 	my $string = "@{$self->{edit_mode_tags}}";
-	my $changed = ($string ne $self->{_edit_mode_string});
-	$self->{_edit_mode_string} = $string;
-	$self->signal_emit('edit_mode_changed') if $changed;
+	return if $string eq $$self{_edit_mode_string};
+
+	$$self{_edit_mode_string} = $string;
+	$self->signal_emit('edit_mode_changed');
 	#warn join ' ', "Mode:", map(
 	#	{$_->{is_link} ? 'link' : $_->get_property('name')}
 	#	@{$self->{edit_mode_tags}}
-	#), "\n" if $changed;
+	#), "\n";
 }
 
 sub _get_open_tags {
@@ -634,6 +656,7 @@ sub toggle_edit_mode_tag {
 	push @tags, $tag
 		if @tags == @{$self->{edit_mode_tags}} and $bool != 0;
 	@{$self->{edit_mode_tags}} = @tags;
+	$$self{_edit_mode_string} = "@{$self->{edit_mode_tags}}";
 	$self->signal_emit('edit_mode_changed');
 }
 
