@@ -1,6 +1,6 @@
 package Gtk2::Ex::HyperTextView;
 
-our $VERSION = '0.24';
+our $VERSION = '0.27';
 
 use strict;
 use vars '%TAGS';
@@ -69,9 +69,10 @@ sub new_with_buffer {
 sub INIT_INSTANCE {
 	my $self = shift;
 	
-	$self->{regular_cursor}  = Gtk2::Gdk::Cursor->new('xterm');
-	$self->{hand_cursor}     = Gtk2::Gdk::Cursor->new('hand2');
-	$self->{hovering_over_link} = 0;
+	$self->{text_cursor} = Gtk2::Gdk::Cursor->new('xterm');
+	$self->{link_cursor} = Gtk2::Gdk::Cursor->new('hand2');
+	$self->{arrow_cursor} = Gtk2::Gdk::Cursor->new('left_ptr');
+	$self->{cursor} = 'text_cursor';
 	$self->{follow_on_enter} = 1;
 	
 	$self->signal_connect_after('realize' => sub {
@@ -215,10 +216,9 @@ sub click_if_link_at_iter {
 	my ($self, $iter) = @_;
 
 	my $link_data = $self->get_link_at_iter($iter);
-	return unless defined $link_data;
-
+	return unless $link_data;
+	
 	$self->signal_emit('link_clicked', $link_data);
-
 	return $link_data;
 }
 
@@ -259,17 +259,149 @@ sub set_cursor_if_appropriate {
 	return unless defined $iter;
 
 	my ($link_tag) = grep {$_->{is_link}} $iter->get_tags;
+	my $cursor = $link_tag ? 'link_cursor': 'text_cursor' ;
 
-	my $hovering = $link_tag ? 1 : 0;
-	if ($hovering != $self->{hovering_over_link}) {
-		$self->{hovering_over_link} = $hovering;
-		my $cursor = $hovering
-			? $self->{hand_cursor}
-			: $self->{regular_cursor} ;
-		$self->get_window('text')->set_cursor($cursor);
+	if ($cursor ne 'link_cursor') {
+		my $pixbuf = $iter->get_pixbuf;
+		unless ($pixbuf) {
+			$iter->backward_char;
+			$pixbuf = $iter->get_pixbuf;
+		}
+		$cursor = 'arrow_cursor'
+			if $pixbuf and $$pixbuf{image_data}{type} eq 'checkbox'
+	}
+
+	if ($cursor ne $self->{cursor}) {
+		$self->{cursor} = $cursor;
+		$self->get_window('text')->set_cursor($$self{$cursor});
 	}
 	
-	return $hovering ? $self->get_link_at_iter($iter, $link_tag) : undef;
+	return ($cursor eq 'link_cursor')
+		? $self->get_link_at_iter($iter, $link_tag)
+		: undef;
+}
+
+=item C<toggle_if_checkbox_at_iter(ITER, TYPE)>
+
+Toggles a checkbox. If type if "x" it uses the "x checked" state, else just normale "v" check.
+
+=cut
+
+sub toggle_if_checkbox_at_iter {
+	my ($self, $iter, $type) = @_;
+	$type = lc $type || 'v';
+	my $pixbuf = $iter->get_pixbuf;
+	unless ($pixbuf and $$pixbuf{image_data}{type} eq 'checkbox') {
+		$iter->backward_char;
+		$pixbuf = $iter->get_pixbuf;
+	}
+	return 0 unless $pixbuf and $$pixbuf{image_data}{type} eq 'checkbox';
+	my $state = $$pixbuf{image_data}{state};
+	$state = ($state == 0 and $type eq 'v') ? 1 :
+	         ($state == 0 and $type eq 'x') ? 2 :
+	         ($state == 2 and $type eq 'v') ? 1 :
+	         ($state == 1 and $type eq 'x') ? 2 : 0 ;
+	my $buffer = $self->get_buffer;
+	my $insert = $buffer->get_insert;
+	my $mark = $buffer->create_mark(
+		'toggle-checkbox-orig-insert',
+		$buffer->get_iter_at_mark($insert),
+		1 );
+	_toggle_checkbox($buffer, $iter, $state);
+	$self->_smart_checkbox_toggle($state) if $$self{use_recurscheck};
+	$buffer->place_cursor( $buffer->get_iter_at_mark($mark) );
+	$buffer->delete_mark($mark);
+	return 1;
+}
+
+sub _toggle_checkbox {
+	my ($buffer, $iter, $state) = @_;
+	my $pixbuf = $iter->get_pixbuf;
+	return $iter unless 
+		$pixbuf and $$pixbuf{image_data}{type} eq 'checkbox';
+	my $offset = $iter->get_offset;
+	my $end = $iter->copy;
+	$end->forward_char;
+	$buffer->delete($iter, $end);
+	$buffer->insert_blocks($iter, ['checkbox', {state => $state}]);
+	return $buffer->get_iter_at_offset($offset);
+}
+
+sub _smart_checkbox_toggle {
+	my ($self, $state) = @_;
+	my $buffer = $self->get_buffer;
+	my $iter = $buffer->get_iter_at_mark( $buffer->get_insert );
+
+	## Check child items
+	my $offset = $iter->get_offset;
+	$self->_check_sublist_items($buffer, $iter, $state, 'UPDATE');
+	$iter = $buffer->get_iter_at_offset($offset);
+
+	while (1) { # loop through all levels in chcekbox list
+		## Find parent
+		my $startline = $iter->get_line;
+		my $line = _get_line($buffer, $iter);
+		$line =~ /(\s*)/;
+		my $prefix = $1;
+		while ($line =~ /^($prefix\s*)\S/) {
+			$iter->backward_line or last;
+			$line = _get_line($buffer, $iter);
+		}
+		# Break loop if no parent found
+		return if $iter->get_line == $startline;
+		return unless $line =~ /^\s*\x{FFFC}/; # parent is in fact a checkbox
+
+		## Check child items for parent - no update
+		$offset = $iter->get_offset;
+		my $ok = $self->_check_sublist_items($buffer, $iter, $state, undef);
+		$iter = $buffer->get_iter_at_offset($offset);
+
+		## Check parent item in sync with children
+		$state = 0 if not $ok;
+		$line = _get_line($buffer, $iter);
+		$line =~ /^(\s*)/;
+		$iter->forward_chars(length $1);
+		$iter = _toggle_checkbox($buffer, $iter, $state);
+	}
+}
+
+sub _check_sublist_items {
+	my ($self, $buffer, $iter, $state, $update) = @_;
+	my $line = _get_line($buffer, $iter);
+	$line =~ /(\s*)/;
+	my $prefix = $1;
+	$iter->forward_line or return 0; # false at end of buffer
+	$line = _get_line($buffer, $iter);
+	my $done = 0; # did we find any items or not
+	while ($line =~ /^($prefix\s+)\S/) {
+		my $level = length $1;
+		if ($line =~ /^\s*\x{FFFC}/) {
+			$iter->forward_chars($level);
+			if ($update) {
+				$iter = _toggle_checkbox($buffer, $iter, $state);
+			}
+			else {
+				my $pixbuf = $iter->get_pixbuf;
+				return 0 unless $pixbuf
+					and $$pixbuf{image_data}{type} eq 'checkbox'
+					and $$pixbuf{image_data}{state} == $state;
+				# check state or return 0
+			}
+			$done = 1;
+		}
+		$iter->forward_line or return $done;
+		$line = _get_line($buffer, $iter);
+	}
+	return $done;
+}
+
+sub _get_line {
+	# FIXME belongs in TextBuffer
+	my ($buffer, $iter) = @_;
+	my $start = $buffer->get_iter_at_line($iter->get_line);
+	my $end = $start->copy;
+	$end->forward_to_line_end;
+	return $buffer->get_slice($start, $end, 1);
 }
 
 # ###### #
@@ -420,11 +552,11 @@ sub on_motion_notify_event {
 	my ($x, $y) = $event->get_coords;
 	   ($x, $y) = $self->window_to_buffer_coords('widget', $x, $y);
 
-	my $hovering  = $self->{hovering_over_link};
+	my $cursor  = $self->{cursor};
 	my $link_data = $self->set_cursor_if_appropriate($x, $y);
 
-	if ($hovering) { # was hovering
-		if ($self->{hovering_over_link}) { # still hovering
+	if ($cursor eq 'link_cursor') { # was hovering
+		if ($self->{cursor} eq 'link_cursor') { # still hovering
 			if ("$link_data" ne $self->{_last_link}) {
 				$self->signal_emit('link_leave');
 				$self->signal_emit('link_enter', $link_data);
@@ -434,7 +566,7 @@ sub on_motion_notify_event {
 		else { $self->signal_emit('link_leave') } # but not anymore
 	}
 	else { # was not hovering
-		if ($self->{hovering_over_link}) { # but hovering now
+		if ($self->{cursor} eq 'link_cursor') { # but hovering now
 			$self->signal_emit('link_enter', $link_data);
 			$self->{_last_link} = "$link_data";
 		}
@@ -484,10 +616,8 @@ sub on_key_press_event {
 }
 
 sub on_button_release_event {
-	# after button press
-
 	my ($self, $event) = @_;
-	return 0 if $event->type ne 'button-release' or $event->button != 1;
+	return 0 if $event->type ne 'button-release';
 
 	# return if user made a selection
 	my ($start, $end) = $self->get_buffer->get_selection_bounds;
@@ -495,9 +625,14 @@ sub on_button_release_event {
 	
 	my $iter = $self->get_iter_at_pointer;
 	return 0 unless defined $iter;
-
-	$self->click_if_link_at_iter($iter);
-
+	if ($event->button == 1) { # left mouse button
+		$self->click_if_link_at_iter($iter)
+			or $self->toggle_if_checkbox_at_iter($iter, 'v');
+	}
+	elsif ($event->button == 3) { # right mouse button
+		$self->toggle_if_checkbox_at_iter($iter, 'x');
+	}
+	
 	return 0;
 }
 
