@@ -7,7 +7,7 @@ use File::Copy ();
 use File::BaseDir 0.03 ();
 	# takes care of $HOME among other stuff
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 eval 'use Zim::OS::Win32' if $^O eq 'MSWin32';
 die $@ if $@;
@@ -295,7 +295,7 @@ Return the path relative to C<parent> if any.
 
 sub dir {
 	my $self = shift;
-	#warn "PARENT $$file{dir} RELPATH $$file{relpath}\n";
+	#warn "PARENT $$self{dir} RELPATH $$self{relpath}\n";
 	if ($$self{dir}) {
 		my @path = split '/', $$self{relpath};
 		pop @path;
@@ -482,7 +482,26 @@ Like C<resolve_file()> but returns a Dir object.
 
 sub file { Zim::FS::File->new(@_) } # File->new() checks for dir object
 
-sub subdir { Zim::FS::Dir->new(@_) } # Dir->new() checks for dir object
+sub subdir {
+	my $self = shift;
+	my $class = ref $self;
+	if (@_ == 1 and ref $_[0]) {
+		# single object argument => we want an existing
+		# directory object to become a child of the current one
+		my $path = Zim::FS->rel_path($_[0], $self);
+		croak "$_[0] can not be a subdir of $self" unless $path;
+		return $self if $path eq '.';
+		return $class->new($self, $path);
+	}
+	elsif (@_ == 1 and $_[0] =~ /^\.\/*$/) {
+		# special case
+		return $self;
+	}
+	else {
+		croak "subdir() needs argument" unless @_;
+		return $class->new($self, @_);
+	}
+}
 
 sub resolve_file { unshift @_, 0; goto \&_resolve }
 
@@ -638,10 +657,12 @@ sub copy_file {
 	croak 'Usage: $dir->copy_file(SOURCE => DEST)' unless @_ == 3;
 	return if $src eq $dest;
 	
+	my $new = !$dest->exists;
 	$dest->dir->touch;
 	warn "## FS copy: $src => $dest\n";
 	File::Copy::copy("$src" => "$dest")
 		or die "Could not copy '$src' to '$dest' ($!)\n";
+	$dest->on_write($new);
 }
 
 sub move_file {
@@ -649,10 +670,12 @@ sub move_file {
 	croak 'Usage: $dir->move_file(SOURCE => DEST)' unless @_ == 3;
 	return if $src eq $dest;
 	
+	my $new = !$dest->exists;
 	$dest->dir->touch;
 	warn "## FS move: $src => $dest\n";
 	File::Copy::move("$src" => "$dest")
 		or die "Could not move '$src' to '$dest' ($!)\n";
+	$dest->on_write($new);
 }
 
 =item C<commit_file(FILE)>
@@ -801,9 +824,13 @@ Returns boolean.
 
 sub exists { -f $_[0]{path} }
 
+=item C<mtime()>
+
+Return the modification time for this file.
+
 =item C<set_mtime()>
 
-Set the mtime for the file as an object attribute.
+Set the current mtime of the file as an object attribute.
 
 =item C<check_mtime()>
 
@@ -813,6 +840,8 @@ when files changed on disk.
 
 =cut
 
+sub mtime { $_[0]{mtime} || ( CORE::stat $_[0]{path} )[9] }
+
 sub set_mtime { $_[0]{mtime} = ( CORE::stat $_[0]{path} )[9] }
 
 sub check_mtime {
@@ -928,12 +957,12 @@ If the file is a symlink this will return the final destination of that link.
 
 sub resolve_link {
 	my $file = shift;
+	my $class = ref($file);
 	while (-l $file) {
 		my $link = readlink($file);
 		die "Could not read link: $!" unless defined $link;
-		$file = Zim::FS::File->new(
+		$file = $class->new(
 			Zim::FS->abs_path($link, $file->dir) );
-		# TODO check if link is within same dir - use dir OO
 	}
 	return $file;
 }
@@ -1112,7 +1141,10 @@ sub on_write {
 	my $self = shift;
 	#warn "move $self->{tmp_path} => $self->{path}\n";
 	File::Copy::move($$self{tmp_path} => $$self{real_path})
-		or die "Could not move '$$self{tmp_path}' to '$$self{real_path}'\n";
+		or die "Could not move '$$self{tmp_path}' to '$$self{real_path}'\n"
+		if -f $$self{tmp_path} ;
+		# The -f check is here because we are also called from
+		# move_file() and copy_file()
 	$self->SUPER::on_write(@_);
 }
 
