@@ -20,7 +20,7 @@ my $has_mimeapplications = $@ ? 0 : 1;
 warn "WARNING: Could not use 'File::MimeInfo::Applications', disabling application bindings\n"
 	unless $has_mimeapplications;
 
-our $VERSION = '0.25';
+our $VERSION = '0.27';
 our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
@@ -30,13 +30,13 @@ Zim::GUI - The application object for zim
 =head1 SYNOPSIS
 
 	use Zim::GUI;
-	
+
 	my $zim = Zim::GUI->new(\%SETTINGS);
 	$zim->gui_init;
 	$zim->gui_show;
-	
+
 	Gtk2->main;
-	
+
 	exit;
 
 =head1 DESCRIPTION
@@ -45,7 +45,7 @@ This is developer documentation, for the user manual try
 executing C<zim --doc>. For commandline options see L<zim>(1).
 
 This module provides the application object for the Gtk2 application B<zim>.
-The application has been split into several components for which the 
+The application has been split into several components for which the
 modules can be found in the Zim::GUI:: namespace. This object brings
 together these components and manages the settings and data objects.
 
@@ -149,6 +149,7 @@ browser
 file_browser
 email_client
 text_editor
+diff_editor
 undo_max	50
 follow_new_link	0
 backsp_unindent	1
@@ -157,14 +158,16 @@ use_camelcase	1
 use_utf8_ent	1
 use_linkfiles	1
 use_autolink	0
+use_autoincr	1
 textfont
 tearoff_menus	0
 use_autoselect	1
 follow_on_enter	1
-use_ctrl_space	1
+use_ctrl_space	0
 ro_cursor	0
 expand_tree	0
 save_interval	5000
+autosave_version 0
 };
 
 our %DEFAULTS;
@@ -196,11 +199,14 @@ NewPage		gtk-new		_New Page	<ctrl>N		New page
 popup_NewPage	gtk-new		_New Page	.		New page
 OpenNotebook	gtk-open	_Open Another Notebook...	<ctrl>O	Open notebook
 Save		gtk-save	_Save		<ctrl>S		Save page
-SaveCopy	gtk-save-as	S_ave A Copy...	<shift><ctrl>S	Save a copy
+SaveVersion	gtk-save-as	S_ave Version...	<ctrl><shift>S	Save Version
+Versions	.		_Versions...	.		Versions
 Export		.		E_xport...	.		Export
 EmailPage	.		_Send To...	.		Mail page
+CopyPage	.		_Copy Page...	.		Copy page
+popup_CopyPage	.		_Copy Page...	.		Copy page
 RenamePage	.		_Rename Page...	F2		Rename page
-popup_RenamePage	.		_Rename Page...	.		Rename page
+popup_RenamePage	.	_Rename Page...	.		Rename page
 DeletePage	.		_Delete Page	.		Delete page
 popup_DeletePage	.	_Delete Page	.		Delete page
 Props		gtk-properties	Proper_ties	.		Properties dialog
@@ -230,10 +236,9 @@ ShowHelpKeys	.		_Keybindings	.		Key bindings
 ShowHelpBugs	.		_Bugs		.		Bugs
 About		gtk-about	_About		.		About
 } );
-#Versions	.		_Versions...	.		Versions
 
 my $ui_toggle_actions = __actions(
-# name,		stock id,	label,		accelerator,	tooltip 
+# name,		stock id,	label,		accelerator,	tooltip
 q{
 TToolBar	.		_Toolbar	.		Show toolbar
 TStatusBar	.		_Statusbar	.		Show statusbar
@@ -256,9 +261,10 @@ my $ui_layout = q{<ui>
 			<menuitem action='OpenNotebook'/>
 			<separator/>
 			<menuitem action='Save'/>
-			<menuitem action='SaveCopy'/>
-			<menuitem action='Export'/>
+			<menuitem action='SaveVersion'/>
+			<menuitem action='Versions'/>
 			<separator/>
+			<menuitem action='Export'/>
 			<placeholder name='PrintActions'/>
 			<menuitem action='EmailPage'/>
 			<separator/>
@@ -359,17 +365,18 @@ my $ui_layout = q{<ui>
 	</toolbar>
 	<popup name='PagePopup'>
 		<menuitem action='popup_NewPage'/>
+		<menuitem action='popup_CopyPage'/>
 		<menuitem action='popup_RenamePage'/>
 		<menuitem action='popup_DeletePage'/>
 	</popup>
 	<accelerator action='GoChild'/>
 </ui>};
-#			<menuitem action='Versions'/>
 
 my $ui_layout_rw = q{<ui>
 <menubar name='MenuBar'>
 		<menu action='FileMenu'>
 			<placeholder name='PageMods'>
+				<menuitem action='CopyPage'/>
 				<menuitem action='RenamePage'/>
 				<menuitem action='DeletePage'/>
 			</placeholder>
@@ -392,18 +399,12 @@ sub init {
 	$self->{app} = $self; # fool base class
 	$self->{_message_timeout} = -1;
 	$self->{_save_timeout}    = -1;
-	
-	# load notebook
-	my $notebook = $self->{notebook}
-		|| Zim->new(
-			dir    => $$self{dir},
-			type   => $$self{type},
-		);
-	$self->{history} = $notebook->init_history();
-	$self->{notebook} = $notebook;
 
+	# check notebook
+	my $notebook = $self->{notebook} or die "BUG: no notebook defined";
+	$self->{history} = $notebook->init_history;
 	$self->{profile} ||= $$notebook{config}{profile} || 'default';
-	
+
 	# load state parameters
 	my %state;
 	for (split /\n/, $STATE) { # defaults
@@ -411,10 +412,12 @@ sub init {
 		my ($key, $val) = split /\s+/, $_, 2;
 		$state{$key} = $val
 	}
-	my $cache_dir = Zim->get_notebook_cache($$notebook{dir});
-	$$self{state_file} =
-		Zim::FS::File::Config->new($cache_dir, 'state.conf');
-	$$self{state} = $$self{state_file}->read(\%state, 'GUI State');
+	my $cache_dir = $notebook->get_notebook_cache;
+	if (defined $cache_dir) {
+		$$self{state_file} =
+			Zim::FS::File::Config->new($cache_dir, 'state.conf');
+		$$self{state} = $$self{state_file}->read(\%state, 'GUI State');
+	}
 
 	# Load config
 	warn "# Profile: $$self{profile}\n";
@@ -465,12 +468,10 @@ sub _load_settings {
 sub _init_properties {
 	my $self = pop; # pop because we are called from signal
 	my $nb = $$self{notebook};
-	
+
 	# name
-	$$self{name} = $$nb{config}{name};
-	$$self{name} ||= $$nb{dir}->name; # we always want a name
-	$self->call_daemon('register', $$self{name});
-	warn "# Notebook: $self->{name}\n";
+	$self->call_daemon('register', $$nb{name});
+	warn "# Notebook: $$nb{name}\n";
 
 	# icon
 	if (my $icon = $$nb{config}{icon}) {
@@ -499,6 +500,14 @@ sub _init_properties {
 	$self->actions_set_sensitive(
 		OpenRootFolder => $$nb{config}{document_root} ? 1 : 0,
 	) if $$self{actions};
+
+	# Check version control
+	if ($$nb{config}{autosave_version} and ! $$nb{vcs}) {
+		eval { $self->SaveVersion };
+			# prompt for init version control
+			# eval in case we are not intialized yet etc.
+		$$nb{config}{autosave_version} = 0 if ! $$nb{vcs};
+	}
 }
 
 sub _config_data_files {
@@ -535,12 +544,12 @@ sub gui_init {
 	else {
 		$window->set_icon_from_file($Zim::ICON);
 	}
-	$window->set_title('Zim');
+	$window->set_title($$self{notebook}{name}.' - Zim');
 	$self->{window} = $window;
 
 	$SIG{USR1} = sub { $window->present };
 		# put window to foreground on `kill -USR1`
-	
+
 	#$window->signal_connect(hide => sub { # FIXME does not work - patched in TrayIcon
 	#		@{$self->{state}}{'x', 'y'} = $window->get_position;
 	#		warn "hiding window: @{$self->{state}}{'x', 'y'}\n";
@@ -550,7 +559,7 @@ sub gui_init {
 			#warn "showing window: $x, $y\n";
 			$window->move($x,$y) if defined($x) and defined ($y);
 		} );
-			
+
 
 	my $vbox = Gtk2::VBox->new(0, 0);
 	$window->add($vbox);
@@ -561,26 +570,26 @@ sub gui_init {
 	$window->add_accel_group($ui->get_accel_group);
 	$ui->set_add_tearoffs($self->{settings}{tearoff_menus});
 	$self->{ui} = $ui;
-	
+
 	$self->add_actions($ui_menus, 'MENU');
 	$self->add_actions($ui_actions);
 	$self->add_actions($ui_toggle_actions, 'TOGGLE');
 	$self->add_actions($ui_radio_actions, 'RADIO', 'TPathBar');
-	
+
 	$self->actions_set_sensitive(
 		Save      => $$self{read_only} ? 0 : 1,
-		SaveCopy  => $$self{read_only} ? 0 : 1,
 		NewPage   => $$self{read_only} ? 0 : 1,
 		GoBack    => 0,
 		GoForward => 0,
 		GoParent  => 0,
-		OpenRootFolder => $$self{notebook}{document_root} ? 1 : 0,
+		OpenRootFolder  => $$self{notebook}{document_root} ? 1 : 0,
+		Versions        => $$self{notebook}{vcs} ? 1 : 0,
 	);
-	
+
 	$self->add_ui($ui_layout);
 	$self->add_ui($ui_layout_rw) unless $self->{read_only};
 		# we do not load menu items for edit whith global read_only
-	
+
 	$self->{menubar} = $ui->get_widget("/MenuBar");
 	$vbox->pack_start($self->{menubar}, 0,1,0);
 	$self->{toolbar} = $ui->get_widget("/ToolBar");
@@ -607,7 +616,7 @@ sub gui_init {
 	$shbox->set_no_show_all(1);
 	$vbox->pack_start($shbox, 0,1,0);
 	$self->{statusbar} = $shbox;
-	
+
 	## Status bar
 	# Page name part
 	my $s1 = Gtk2::Statusbar->new;
@@ -643,7 +652,7 @@ sub gui_init {
 	$s2->set_size_request(80,10);
 	$shbox->pack_end($s2, 0,1,0);
 	$self->{status2} = $s2;
-	
+
 	$ebox->signal_connect_swapped(button_press_event => \&on_click_backlinks, $self);
 
 	## Build content of the main area
@@ -657,7 +666,7 @@ sub gui_init {
 
 	$vbox->set_focus_chain($l_vbox, $page_view->widget);
 		# get pathbar and toolbar out of the loop
-	
+
 	my $hist = $self->{history};
 	$hist->set_GUI($page_view) if $hist;
 
@@ -666,7 +675,7 @@ sub gui_init {
 	# Ctrl-Space / Alt-Space
 	my @combo = ([ord(' '), ['mod1-mask']]);
 	push @combo, [ord(' '), ['control-mask']] if $self->{settings}{use_ctrl_space};
-	$accels->connect( 
+	$accels->connect(
 		@$_, ['visible'],
 		sub {
 			if ($self->{state}{pane_vis}) {
@@ -751,14 +760,14 @@ sub gui_init {
 
 =item C<gui_show()>
 
-This method actually shows the main window. This is separated from 
+This method actually shows the main window. This is separated from
 C<gui_init()> so we can first load a page before showing the GUI.
 
 =cut
 
 sub gui_show {
 	my ($self, %opt) = @_;
-	
+
 	## Show all widgets .. well most of them
 	$self->{ui}->ensure_update; # make sure the menu is complete
 	$self->{vbox}->show_all;
@@ -766,20 +775,26 @@ sub gui_show {
 	$self->{l_vbox}->set_no_show_all(0);
 	$self->{toolbar}->set_no_show_all(0);
 	$self->ShowWindow(%opt); # run before "load_page" to prevent lag
-	
+
 	## Find a page to load
 	my $hist = $self->{history};
 	unless ($self->{page}) {
-		my $page = $hist ? $hist->get_current : undef;
-		$page ||= $self->{home};
-		$page = ref($page)
-			? $page
-			: $self->{notebook}->resolve_page($page);
+		my $page;
+		$page = $$self{history}->get_current if $$self{history} ;
+		$page ||= $$self{notebook}->resolve_page($$self{home})
+			if $$self{home};
+		unless ($page) {
+			# last ditch effort
+			($page) = $$self{notebook}->list_pages(':');
+			$page = $$self{notebook}->resolve_name($page);
+		}
 		$self->load_page($page);
 	}
-	
+
 	## Toggle some widgets
 	$self->{message_lock} = 1;
+	$self->TReadOnly($$self{page}{properties}{read_only}||0, 'FORCE');
+		# force emission after first page load
 	my $set = $self->{settings};
 	my $pbtype = lc $$set{pathbar_type};
 	$pbtype = 'recent' unless grep {$_ eq $pbtype}
@@ -795,11 +810,11 @@ sub gui_show {
 
 	## set autosave interval - default is every 5 seconds
 	my $t = $$set{save_interval} || 5000;
-	$self->{_save_timeout} = 
+	$self->{_save_timeout} =
 		Glib::Timeout->add($t, sub {$self->SaveIfModified('SOFT'); 1})
 		unless $self->{read_only};
 		# global read-only - so we never need to save
-	
+
 	$self->signal_emit('gui_show');
 	$self->PageView->grab_focus;
 }
@@ -865,7 +880,8 @@ sub DESTROY {
 	my $self = shift;
 	for (qw/_save_timeout _message_timeout/) {
 		my $timeout = $self->{$_};
-		Glib::Source->remove($timeout) if $timeout >= 0;
+		Glib::Source->remove($timeout)
+			if defined $timeout and $timeout >= 0;
 	}
 }
 
@@ -873,20 +889,22 @@ sub AUTOLOAD {
 	my $self = shift;
 	my $class = ref $self;
 	$AUTOLOAD =~ s/^.*:://;
-	
+
 	return if $AUTOLOAD eq 'DESTROY';
 	croak "No such method: $class::$AUTOLOAD" unless ref $self;
 	#warn join ' ', "Zim::AUTOLOAD called for $AUTOLOAD by: ", caller, "\n";
-	
+
 	if (exists $self->{objects}{$AUTOLOAD}) {
 		return $self->{objects}{$AUTOLOAD};
 	}
 	elsif ($AUTOLOAD =~ /^on_(\w+)$/) { # could be an action handler
 		no strict 'refs';
+		unshift @_, $self;
 		goto &{"Zim::GUI::Component::$AUTOLOAD"}; # call parent
 	}
 	elsif ($AUTOLOAD =~ /^[A-Z]/) {
-		my $class = "Zim::GUI::$AUTOLOAD";
+		my $class = $$self{autoload}{$AUTOLOAD};
+		$class ||= "Zim::GUI::$AUTOLOAD";
 		warn "## AUTOLOAD $class\n";
 		eval "require $class";
 		$self->exit_error($@) if $@;
@@ -894,38 +912,13 @@ sub AUTOLOAD {
 		return $self->{objects}{$AUTOLOAD};
 	}
 
-	
+
 	# Call method on default widget
 	croak "No such method: $class::$AUTOLOAD"
 		unless $$self{window} and $$self{window}->can($AUTOLOAD);
 	return $self->{window}->$AUTOLOAD(@_);
 }
 
-sub on_delete_event {
-	# Called when the window is deleted
-	# return true to avoid destruction
-	my $self = shift;
-	my $force = uc(shift) eq 'FORCE';
-
-	eval {
-		my ($state, $window) = @{$self}{'state', 'window'};
-		@{$state}{'width', 'height'} = $window->get_size;
-		@{$state}{'x', 'y'} = $window->get_position if $window->visible;
-			# position is 0,0 when window is hidden
-	};
-	
-	if ($self->{hide_on_delete} and !$force) {
-		$self->{window}->hide;
-		return 1;
-	}
-	
-	$self->SaveIfModified() || return 1;
-	$self->SaveState;
-	$self->{history}->write if $self->{history}; # Save history
-
-	return 0;
-}
-
 =item C<current()>
 
 Returns a reference to the current Zim::GUI object. Class method used in plugin
@@ -950,7 +943,7 @@ sub plug { # TODO add plugin to config
 	return $self->error_dialog(
 		__("Plugin already loaded: {name}", name => $name) )
 		if $self->{plugins}{$name};
-		
+
 	my ($script) = data_files('zim', 'plugins', $name.'.pl');
 	unless (length $script) {
 		$self->unplug($name);
@@ -958,13 +951,14 @@ sub plug { # TODO add plugin to config
 			__("No such plugin: {name}", name => $name) );
 	}
 
-	warn "# Loading plugin $name from $script\n";
+	warn "# Loading plugin $name\n";
+	warn "## from $script\n";
 	local $CURRENT = $self;
 	my $return = do $script;
 	if ($@ or ! defined $return) {
 		$self->unplug($name);
 		return $self->error_dialog(
-			__("Failed to load plugin: {name}", name => $name),
+			__("Failed to load plugin: {name}", name => $name), #. error
 			$@ || $! );
 	}
 
@@ -982,17 +976,17 @@ sub unplug {
 sub on_click_backlinks {
 	my ($self, $event) = @_;
 	return if $event->type ne 'button-press';
-	
+
 	if ($event->button == 1) {
 		$self->SearchDialog->{dialog}
 			? $self->SearchDialog->hide
 			: $self->SearchBL  ;
 	}
 	return unless $event->button == 3;
-	
+
 	my @blinks = $self->{page}->list_backlinks;
 	return unless @blinks;
-	
+
 	my $menu = Gtk2::Menu->new();
 	for my $l (@blinks) {
 		my $item = Gtk2::ImageMenuItem->new_with_label($l);
@@ -1002,7 +996,7 @@ sub on_click_backlinks {
 	}
 
 	$menu->show_all;
-	
+
 	my ($button, $time) = $event
 		? ($event->button, $event->time)
 		: (0, 0) ;
@@ -1036,13 +1030,15 @@ sub SaveSettings {
 	my $file = config_home('zim', $$self{profile}.'.conf');
 	warn "# Writing config to: $file\n";
 	Zim::FS::File::Config->new($file)->write(\%conf, 'Config');
+	$self->signal_emit('settings-changed');
 	$self->call_daemon('broadcast', 'LoadSettings') if $notify;
 }
 
 sub SaveState {
 	my $self = shift;
 	$$self{state}{pane_pos} = $$self{hpaned}->get_position;
-	$$self{state_file}->write($$self{state}, 'GUI State');
+	$$self{state_file}->write($$self{state}, 'GUI State')
+		if $$self{state_file};
 }
 
 =item C<LoadSettings()>
@@ -1095,14 +1091,14 @@ LINK is a file or an url.
 sub link_clicked {
 	my ($self, $link) = @_;
 	$link =~ s/^\s+|\s+$//g; # no whitespace pre- or post-fix
-	#warn "link clicked: >>$link<<\n";
 	return warn "WARNING: You tried to folow an empty link.\n"
 		unless length $link;
 
 	my ($type, $l) = $self->{page}->parse_link($link);
+	warn "## Link clicked: $link ($type: $l)\n";
 	return $self->error_dialog("Link undefined: $link")
 	       unless defined $type;
-	
+
 	if    ($type eq 'page') { $self->load_page($l) }
 	elsif ($type eq 'file') { $self->open_file($l) }
 	elsif ($type eq 'zim') {
@@ -1111,7 +1107,7 @@ sub link_clicked {
 		my $page = $1;
 		$self->OpenNotebook($l, $page) if length $l;
 	}
-	elsif ($type eq 'man')  { $self->ShowHelp(':man:'.$l)  }
+	elsif ($type eq 'man')  { $self->ShowHelp('_man_', $l) }
 	else                    { $self->open_url($l, $type)   }
 }
 
@@ -1126,7 +1122,7 @@ sub open_file {
 	my ($self, $file) = @_;
 	return $self->open_directory($file) if $file =~ /\/$/ or -d $file;
 		# Just to make sure we are dealing with files here
-	
+
 	my $app;
 	if ($has_mimeapplications) {
 		my $mt = mimetype("$file");
@@ -1163,18 +1159,18 @@ sub open_directory {
 	my ($self, $dir, $open_file) = @_;
 		# open_file is a private arg used by open_file() to
 		# flag that we try to open a file instead of a dir
-	
+
 	my $browser = $self->_ask_app('file_browser', __('File browser')) #. application type
 		or return 0;
-	
+
 	$dir = Zim::FS->localize($dir);
 	my $file = $dir;
-	if ($open_file) {
+	if ($open_file or -f $dir) {
 		# Get rid of the file part of the path
 		my ($vol, $dirs, undef) = File::Spec->splitpath($dir);
 		$dir = File::Spec->catpath($vol, $dirs);
 	}
-	
+
 	unless (-d $dir) {
 		# Check existense of the directory part
 		my $answer = $self->prompt_question( 'question',
@@ -1184,13 +1180,20 @@ sub open_directory {
 		$dir->touch;
 	}
 
-	$browser =~ s/\%([fds])/($1 eq 'f') ? $file : $dir/eg
-		or $browser .= " \"$dir\"";
+	if ($open_file) {
+		$browser =~ s/\%([fds])/($1 eq 'f') ? $file : $dir/eg
+			or $browser .= " \"$dir\"";
 		# %f means the filebrowser can open files directly
 		#    this can be used if we don't have mime libraries
 		#    but the filebrowser knows how to do it.
 		# %d means we only try to open directories
 		# %s is same as %d and is included for backwards compatibility
+	}
+	else {
+		$browser =~ s/\%([fds])/$dir/eg
+			or $browser .= " \"$dir\"";
+	}
+
 	Zim::Utils->run($browser);
 	return 1;
 }
@@ -1225,7 +1228,7 @@ Opens URL in the web browser.
 sub open_url {
 	my ($self, $url, $type) = @_;
 	# type is a private argument used for error handling for interwiki
-	
+
 	$url =~ /^(\w[\w\+\-\.]+):/
 		or return $type
 			? $self->error_dialog(
@@ -1233,7 +1236,7 @@ sub open_url {
 			: $self->error_dialog(
 				__("Not an url: {url}", url => $url)) ;
 	my $proto = $1;
-	
+
 	my ($app, $string) = ($proto eq 'mailto')
 		? ('email_client', __('Email client'))   #. application type
 		: ('browser',      __('Web browser' )) ; #. application type
@@ -1264,20 +1267,20 @@ sub load_page {
 sub _load_page { # load _without_ saving first
 	my ($self, $page) = @_;
 	my $prevpage = $self->{page};
-	
+
 	# See if we got a name, a page or a history record
 	my ($rec, $name);
-	($name, $page, $rec) = 
+	($name, $page, $rec) =
 		(ref($page) eq 'HASH') ? ($page->{name}, undef, $page) :
 		 ref($page)            ? ($page->name,   $page, undef) :
 		                         ($page,         undef, undef) ;
 	warn "## GUI load_page: $name (obj: $page rec: $rec)\n";
-	
+
 	# Get page if we didn't get it as argument
 	unless ($page) {
 		return warn "WARNING: You tried to load an empty name.\n"
 			unless length $name;
-		
+
 		eval { $page = $self->{notebook}->get_page($name) };
 		return $self->error_dialog(
 			__("Could not load page: {name}", name => $name)."\n\n$@", $@) if $@;
@@ -1294,7 +1297,7 @@ sub _load_page { # load _without_ saving first
 		$page->{properties}{read_only} = 1;
 		$page->{properties}{is_error} = 404;
 	}
-	
+
 	# Update history if we didn't get a record as argument
 	# if we did get a record it is from GoBack() or GoForw()
 	# and the history is updated already
@@ -1310,7 +1313,7 @@ sub _load_page { # load _without_ saving first
 		$self->exit_error(__("Could not load page: {name}", name => $name)."\n\n$@", $@);
 		# TODO handle more gratiously .. use read_only ?
 	}
-	
+
 	# Update various objects
 	$self->{objects}{PageView}->set_state($rec->{state})
 		if $rec and $rec->{state};
@@ -1319,12 +1322,11 @@ sub _load_page { # load _without_ saving first
 		and (defined $prevpage and ! $prevpage->exists);
 	$self->TReadOnly($$page{properties}{read_only}||0);
 	$self->signal_emit('page_loaded', $name);
-	
-	$self->{window}->set_title("$name - Zim");
+
 	$self->update_status();
 	my $links = scalar $page->list_backlinks;
 	$self->{statusl}->set_text_with_mnemonic(
-		__("{number} _Back links", number => $links).'...');
+		__n("{number} _Back link", "{number} _Back links", number => $links).'...' );
 
 	$self->{history}->write if $self->{history}; # Save history
 }
@@ -1337,18 +1339,20 @@ This emits the C<t_read_only> signal.
 =cut
 
 sub TReadOnly {
-	my ($self, $read_only) = @_;
+	my ($self, $read_only, $force) = @_; # force is a private arg
 	$read_only = $$self{read_only} ? 0 : 1 unless defined $read_only;
-	#my @c = caller; warn "TR get $read_only ($$self{read_only}, $$self{read_only_lock}) from $c[0] $c[2]\n";
-	return if $$self{read_only_lock};
-	return if $read_only == $$self{read_only};
+	#my @c = caller; warn "TR get $read_only ($$self{read_only}, $$self{read_only_lock}) from @c\n";
+	unless ($force) {
+		return if $$self{read_only_lock};
+		return if $read_only == $$self{read_only};
+	}
 	$$self{read_only} = $read_only;
 	$self->actions_set_sensitive(
 		Save => !$read_only,
 	);
 	#warn "Emit t_read_only => $read_only\n";
 	$self->signal_emit(t_read_only => $read_only);
-	$self->update_status; 
+	$self->update_status;
 		# We want to show "[read-only]" in the statusbar
 }
 
@@ -1371,8 +1375,8 @@ PAGE is used to fill in the namespace in the dialog.
 sub NewPage {
 	my ($self, $ns) = @_;
 
-	if (defined $ns) { $ns =~ s/[^:]+$// }
-	else { $ns = $self->{page}->namespace }
+	$ns ||= $self->{page};
+	$ns =~ s/:?$/:/;
 	$ns = '' if $ns eq ':';
 
 	my $values = $self->run_prompt(
@@ -1390,7 +1394,7 @@ sub NewPage {
 
 	$self->load_page(
 		$self->{notebook}->resolve_name($page, $self->{page}) );
-	
+
 	$self->Save unless $$self{page}->exists; # touch new page
 }
 
@@ -1404,13 +1408,16 @@ When NOTEBOOK is given PAGE can be used to open the notebook at a certain page.
 
 sub OpenNotebook {
 	my ($self, $notebook, $page) = @_;
-	return $self->NotebookDialog->show() unless defined $notebook;
+	$notebook = '_new_' unless defined $notebook;
+	$page = $page->name if ref $page;
+
+	# first try the daemon
+	$self->call_daemon('open', $notebook, $page) and return;
+
+	# We are not using daemon or daemon failed
+	return $self->NotebookDialog->show() if $notebook eq '_new_';
 		# Don't wait for return - NotebookDialog is not modal
 
-	$page = $page->name if ref $page;
-	$self->call_daemon('open', $notebook, $page) and return;
-	
-	# We are not using daemon or daemon failed
 	$notebook = Zim::FS->localize($notebook)
 		if $notebook =~ m#/#; # path
 	return $self->exec_new_window($notebook, $page);
@@ -1445,9 +1452,9 @@ sub SaveIfModified {
 	return 1 if $self->{read_only};
 		# even if modified due to bug no save for read_only
 	return 0 if $self->{save_lock} and $soft;
-	
+
 	my $modified = $self->{objects}{PageView}->modified;
-	
+
 	warn "## GUI SaveIfModified\n" if $modified;
 	return $self->_save_page($modified, !$soft);
 }
@@ -1457,7 +1464,7 @@ sub SaveIfModified {
 sub _save_page {
 	my ($self, $save, $commit) = @_;
 	$self->{save_lock} = 1; # Used to block autosave while "could not save" dialog
-	
+
 	my $page = $self->{page};
 	eval {
 		$self->PageView->save_page($page) if $save;
@@ -1468,7 +1475,7 @@ sub _save_page {
 		warn 'ERROR: '.$error;
 		my $answer = $self->prompt_question( 'error',
 			'<b>'.__("Could not save page")."</b>\n\n$error", # dialog message
-			['cancel', 'gtk-cancel', undef ], 
+			['cancel', 'gtk-cancel', undef ],
 			['discard', 'gtk-delete', __('_Discard changes')], #. dialog button
 			['copy', 'gtk-save-as', __('_Save a copy...')], #. dialog button
 			3 );
@@ -1477,7 +1484,7 @@ sub _save_page {
 			$self->_load_page($self->{page}); # load page wihtout saving
 		}
 		elsif ($answer eq 'copy') {
-			return $self->SaveCopy; # recurs indirectly
+			return $self->CopyPage; # recurs indirectly
 		}
 		else { return 0 } # return _without_ removing save_lock
 	}
@@ -1487,56 +1494,162 @@ sub _save_page {
 	return 1;
 }
 
-=item C<SaveCopy()>
+=item C<SaveVersion(COMMENT)>
 
-Prompt the user to save a copy of the current page.
+Prompt for a comment and commit a version. COMMENT is an optional argument
+and will be used as the suggested comment in the dialog.
 
-=cut
-
-sub SaveCopy {
-	my $self = shift;
-	return unless $self->{page};
-
-	# prompt page
-	my $new = __('{name}_(Copy)', name => $self->{page}->name); #. default name for new page in save copy action
-	my $val = $self->run_prompt(
-		__('Save Copy'), #. dialog title
-		['page'], {page => [__('Page'), 'page', $new]}, #. enrty label
-		'gtk-save-as', __('_Save Copy'), #. save button
-		__('Please enter a name to save') ); #. dialog text
-	return unless defined $val;
-	($new) = @$val;
-	return unless length $new;
-
-	my $l = $self->check_page_input($new);
-	my $page = $self->{notebook}->resolve_page($l);
-	return $self->error_dialog(
-		__("Can not save to page: {name}", name => $l) )
-		unless $page;
-	
-	# check if page exists
-	if ($page->exists()) {
-		my $answer = $self->prompt_question( 'warning',
-			__("<b>Page already exists</b>\n\nThe page '{name}'\nalready exists.\nDo you want to overwrite it?", name => $new), #. warning dialog, answers are 'cancel' or 'ovewrite'
-			['cancel', 'gtk-cancel', undef],
-			['overwrite', undef, __('_Overwrite')] ); #. save button
-		return unless $answer eq 'overwrite';
-	}
-	
-	# change page and save buffer
-	$self->{page} = $page;
-	$self->Save;
-	$self->Reload;
-}
+If no version control is enabled prompt for initializing version control.
 
 =item C<Versions()>
 
 Show the versions dialog, see L<Zim::GUI::VersionsDialog>.
 
+=item C<init_vcs_dialog()>
+
+Prompt user to initialize version control, called by C<SaveVersion()>.
+
 =cut
 
+sub SaveVersion {
+	my ($self, $comment) = @_;
+	$self->SaveIfModified or return;
+
+	return $self->init_vcs_dialog unless $$self{notebook}{vcs};
+
+	# saved log
+	my $cache_dir = $$self{notebook}->get_notebook_cache;
+	my $log = defined($cache_dir)
+		? $cache_dir->file('version-comment.txt')
+		: undef ;
+	if (defined $log and $log->exists) {
+		$comment =~ s/\n?$/\n\n/ if $comment =~ /\S/;
+		$comment .= $log->read;
+	}
+	else { $comment ||= "Saved version from zim" }
+
+	# prompt for comment
+	my $dialog = Gtk2::Dialog->new(
+		__('Save version').' - Zim', $$self{window}, #. dialog title
+		[qw/modal destroy-with-parent no-separator/],
+		'gtk-help' => 'help',
+		'gtk-cancel' => 'cancel',
+		'gtk-save' => 'ok'
+	);
+	#$dialog->vbox->set_spacing(5);
+	$dialog->set_default_size(300, 150);
+
+	my $vpane = Gtk2::VPaned->new;
+	$dialog->vbox->add($vpane);
+	my $vbox1 = Gtk2::VBox->new;
+	$vpane->add1($vbox1);
+	my $vbox2 = Gtk2::VBox->new;
+	$vpane->add2($vbox2);
+
+	# label and input text field
+	$vbox1->pack_start(
+		Gtk2::Label->new(__('Please enter a comment for this version')), #. dialog text
+		0,1,0 );
+	my ($scroll, $view) = $self->new_textview;
+	$view->get_buffer->set_text( $comment ) if $comment =~ /\S/;
+	$view->set_editable(1);
+	$vbox1->add($scroll);
+
+	# status
+	my $label = Gtk2::Label->new('<b>'.__('Details').'</b>'); #. label
+	$label->set_use_markup(1);
+	$label->set_alignment(0,0.5);
+	$vbox2->pack_start($label, 0,1,0);
+
+	my ($stscroll, $stview) = $self->new_textview(
+		$$self{notebook}{vcs}->status );
+	$vbox2->add($stscroll);
+	my $hbox = Gtk2::HBox->new;
+	$vbox2->pack_start($hbox, 0,1,0);
+	my $cbutton = Gtk2::Button->new(__('_Notebook Changes...')); #. button
+	$cbutton->signal_connect(clicked =>
+		sub { $self->VersionsDialog->Diff } );
+	$hbox->pack_end($cbutton, 0,1,0);
+
+	# and run
+	$dialog->show_all;
+	while (my $re = $dialog->run) {
+		if ($re eq 'help') {
+			$self->ShowHelp(':Usage:VersionControl');
+			next;
+		}
+
+		my ($start, $end) = $view->get_buffer->get_bounds;
+		$comment = $view->get_buffer->get_text($start, $end, 0);
+		$log->write($comment) if defined $log and $comment =~ /\S/;
+			# write log for next instance of this dialog
+		$dialog->destroy;
+		if ($re eq 'ok') {
+			return $self->error_dialog(
+				__('Can not save a version without comment') ) #. error
+				unless $comment =~ /\S/;
+			eval { $$self{notebook}{vcs}->commit($comment) };
+			return $self->error_dialog(
+				__('Could not save version')."\n\n$@") if $@; #. error
+			$log->remove if defined $log;
+				# if commit succesfull log can be deleted
+		}
+		last;
+	}
+}
+
 sub Versions { pop->VersionsDialog->show() }
 
+sub init_vcs_dialog {
+	my $self = shift;
+
+	my $text = __("<b>Enable Version Control</b>\n\nVersion control is currently not enabled for this notebook.\nDo you want to enable it ?") #. question dialog, options are 'help', 'cancel' and 'ok'
+	         . "\n\n"
+		 . __("You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.\nPlease click 'help' to read about the system requirements.") ; #. detailed notice in prompt to enable version control
+	my $answer = $self->prompt_question(
+		'question', $text,
+		[help   => 'gtk-help'],
+		[cancel => 'gtk-cancel'],
+		[svn    => undef, 'Subversion' ],
+		[bzr    => undef, 'Bazaar'],
+	);
+
+	my $vcs = undef;
+	my $args = {};
+	if ($answer eq 'bzr') { $vcs = 'Bazaar' }
+	elsif ($answer eq 'svn') {
+		my $val = $self->run_prompt(
+			'Enter SVN repository',
+			['url','username','password'],
+			{
+				url => ['SVN repository URL', 'string', 'http://'],
+				username => ['Username', 'string', ''],
+				password => ['Password', 'password', ''],
+			}
+		);
+		return unless $val;
+		$args = {
+			'url' => $$val[0],
+			'username' => $$val[1],
+			'password' => $$val[2],
+		};
+		$vcs = 'Subversion';
+	}
+	elsif ($answer eq 'help') {
+		$self->ShowHelp(':Usage:VersionControl');
+		return;
+	}
+	else { return }
+
+	if (defined $vcs) {
+		eval { $$self{notebook}->init_vcs($vcs, $args) };
+		return $self->error_dialog( __('Could not initialize version control')."\n\n$@" ) if $@ or ! $$self{notebook}{vcs}; #. error dialog
+		$self->Reload; # purge page object
+		$self->actions_set_sensitive(Versions => 1);
+		$self->SaveVersion( __("Initial version") ) # indirect recurs #. default comment for first version after initializing version control
+	}
+}
+
 =item C<Export()>
 
 Show the export dialog, see L<Zim::GUI::ExportDialog>.
@@ -1560,6 +1673,53 @@ sub EmailPage {
 	$self->open_url("mailto:?subject=$subject&body=".$src);
 }
 
+=item C<CopyPage()>
+
+Prompt the user to save a copy of the current page.
+
+=cut
+
+sub CopyPage {
+	my ($self, $page) = @_;
+	$page ||= $$self{page};
+
+	my $copy_current = $$self{page}->equals($page);
+	my $save = $self->SaveIfModified(!$copy_current);
+	return 0 if $copy_current and !$save;
+
+	# prompt page
+	my $new = __('{name}_(Copy)', name => $page); #. default name for new page in save copy action
+	my $val = $self->run_prompt(
+		__('Save Copy'), #. dialog title
+		['page'], {page => [__('Page'), 'page', $new]}, #. enrty label
+		'gtk-save-as', __('_Save Copy'), #. save button
+		__('Please enter a name to save a copy of page: {page}', page => $page) ); #. dialog text
+	return unless defined $val;
+	($new) = @$val;
+	return unless length $new;
+
+	my $l = $self->check_page_input($new);
+	$new = $self->{notebook}->resolve_page($l);
+	return $self->error_dialog(
+		__("Can not save to page: {name}", name => $l) )
+		unless $new;
+
+	# check if page exists
+	if ($new->exists()) {
+		my $answer = $self->prompt_question( 'warning',
+			__("<b>Page already exists</b>\n\nThe page '{name}'\nalready exists.\nDo you want to overwrite it?", name => $new), #. warning dialog, answers are 'cancel' or 'ovewrite'
+			['cancel', 'gtk-cancel', undef],
+			['overwrite', undef, __('_Overwrite')] ); #. save button
+		return unless $answer eq 'overwrite';
+	}
+
+	# finally copy page
+	$$self{notebook}->copy_page($page => $new);
+	$self->signal_emit(page_created => $new);
+
+	return 1;
+}
+
 =item C<RenamePage(FROM, TO, UPDATE_SELF, UPDATE_OTHER)>
 
 Wrapper for C<< Zim->move_page() >>.
@@ -1580,11 +1740,11 @@ sub RenamePage {
 	my ($self, $from, $to, @update) = @_;
 
 	$from = $self->{page}->name unless defined $from;
-	
+
 	my $move_current = $self->{page}->equals($from);
 	my $save = $self->SaveIfModified(!$move_current);
 	return 0 if $move_current and !$save;
-	
+
 	unless (defined $to) {
 		($to, @update) = $self->prompt_rename_page_dialog($from);
 		$self->check_page_input($to);
@@ -1601,7 +1761,7 @@ sub RenamePage {
 	# Get backlinks
 	my $rfrom = $move_current ? $self->{page} : $self->{notebook}->get_page($from); # FIXME ugly lookup
 	my @backlinks = $rfrom->list_backlinks();
-	
+
 	# Move page
 	#warn "Move '$from' to '$to'\n";
 	eval { $self->{notebook}->move_page($from, $to) };
@@ -1641,12 +1801,12 @@ sub RenamePage {
 		$self->error_dialog($@) if $@;
 		$dialog->destroy;
 	}
-	
+
 	warn "# moved $from => $to\n";
 	$self->{history}->delete_recent("$from") if $self->{history};
 	$self->signal_emit('page_renamed', $from => $to);
 	$self->load_page($to) if $move_current;
-	
+
 	$self->update_status;
 	return 1;
 }
@@ -1664,23 +1824,23 @@ TODO: make recusive delete work
 
 sub DeletePage {
 	# FIXME option to delete a complete sub-tree
-	# FIXME integrate with the save_page() logic, now we have 
+	# FIXME integrate with the save_page() logic, now we have
 	# redundant code here
 	my ($self, $page, undef, $noconf) = @_;
 	$page = $self->{page}->name unless defined $page;
-	
+
 	my $name = ref($page) ? $page->name : $page;
 	my $delete_current = ($name eq $self->{page}->name);
 	$self->SaveIfModified(!$delete_current);
-	
+
 	unless ($noconf) {
 		my $r = $self->prompt_question( 'warning',
-		__("<b>Delete page</b>\n\nAre you sure you want to delete\npage '{name}' ?", name => $name), #. warning dialog, answers are 'yes' or 'no'
+		__("<b>Delete page</b>\n\nAre you sure you want to delete\npage '{name}' ?", name => $name), #. warning dialog, answers are 'cancel' or 'delete'
 			['no',  'gtk-cancel', undef],
 			['yes', 'gtk-delete', undef]  );
 		return unless $r eq 'yes';
 	}
-	
+
 	$page = $self->{page} if $delete_current; # make sure we have the right object
 	eval { $self->{notebook}->delete_page($page) };
 	return $self->error_dialog(
@@ -1715,17 +1875,63 @@ Quit the application. Also closes all other instances of zim.
 =cut
 
 sub Close {
-	my $self = shift;
-	$self->on_delete_event(@_) && return;
-	Gtk2->main_quit;
+	$_[0]->on_delete_event($_[1]) || Gtk2->main_quit;
 }
 
 sub Quit {
 	$_[0]->call_daemon('broadcast', 'Close', 'FORCE');
-	$_[0]->call_daemon('main_quit');
 	$_[0]->Close('FORCE');
 }
 
+sub on_delete_event {
+	# Called when the window is deleted or by the Close action
+	# return true to avoid destruction in both cases
+	my $self = shift;
+	my $force = uc(shift) eq 'FORCE';
+
+	# try to get window state, eval because window may be destroyed already
+	eval {
+		my ($state, $window) = @{$self}{'state', 'window'};
+		@{$state}{'width', 'height'} = $window->get_size;
+		@{$state}{'x', 'y'} = $window->get_position if $window->visible;
+			# position is 0,0 when window is hidden
+	};
+
+	# save state etc. no matter if we really destruct or not
+	$self->SaveIfModified() || return 1;
+	$self->SaveState;
+	$$self{history}->write if $$self{history}; # Save history
+
+	# Hide window already to make it look snappy
+	$$self{window}->hide;
+	while (Gtk2->events_pending) { Gtk2->main_iteration_do(0) }
+
+	# clean up tmp files - match name Zim::FS->tmp_file
+	my $dir = dir( Zim::FS->tmpdir );
+	my @files = grep /^zim-$ENV{USER}-$$-/, $dir->list;
+	for (@files) {
+		eval { $dir->file($_)->remove };
+		warn $@ if $@;
+	}
+
+	# check if we really destruct or not
+	return 1 if $$self{hide_on_delete} and !$force;
+
+	# autosave version
+	eval { $$self{notebook}{vcs}->commit("Autosave version from zim") }
+		if  $$self{notebook}{vcs}
+		and $$self{notebook}{config}{autosave_version} ;
+
+	# check umounting
+	my $mount = $$self{notebook}{automount};
+	eval {
+		my $path = $$self{notebook}{file} || $$self{notebook}{dir} ;
+		Zim::GUI::Automount->umount($path, $mount);
+	} if $mount ;
+
+	return 0 
+}
+
 =item C<CopyLocation(PAGE, ...)>
 
 Copies a list of page names to the clipboard.
@@ -1875,7 +2081,7 @@ sub on_TPathBar {
 sub TPathBar {
 	my ($self, $type) = @_;
 	return warn "BUG: No pathbar type given" unless defined $type;
-	
+
 	my $path_bar = $self->{objects}{PathBar};
 	if (grep {$type eq $_} qw/recent history namespace/) {
 		$path_bar->widget->show_all;
@@ -1939,7 +2145,7 @@ sub OpenFolder {
 	return $self->error_dialog(
 		__("This page does not have a document folder") ) #. error
 		unless $dir;
-	
+
 	# open_directory asks to create directory if it doesn't exist
 	my $ok = $self->open_directory($dir);
 	if (! $ok) {
@@ -1961,36 +2167,40 @@ sub OpenRootFolder {
 	$self->open_directory($dir);
 }
 
-=item C<EditSource()>
+=item C<EditSource(PAGE)>
 
-Open the current page in an external editor.
+Open PAGE or the current page in an external editor.
 
 =cut
 
 sub EditSource {
-	my $self = shift;
-	$self->SaveIfModified;
-	my $page = $self->{page};
+	my ($self, $page, $file) = @_; # file is a private argument
+	# If file is given it could be e.g. a config file, in this 
+	# case we do not do anything with pages.
+	unless ($file) {
+		$self->SaveIfModified;
+		$page ||= $self->{page};
+
+		# Write source to tmp file
+		return $self->error_dialog(__("This page does not have a source"))
+			unless $page->has_source;
+		my $fh = $page->open_source('r');
+		$file = Zim::FS->tmp_file('EditSource.txt');
+		$file->write(<$fh>);
+		$fh->close;
+	}
 
-	# Write source to tmp file
-	return $self->error_dialog(__("This page does not have a source"))
-		unless $page->has_source;
-	my $fh = $page->open_source('r');
-	my $file = Zim::FS->tmp_file('EditSource.txt');
-	$file->write(<$fh>);
-	$fh->close;
-	
 	# Find editor
 	my $editor = $self->_ask_app('text_editor', __('Text Editor')) #. application type
 		or return;
 	$editor =~ s/\%[sf]/$file/ or $editor .= " \"$file\"";
-	
+
 	# Execute - GUI will hang while waiting for system to return,
 	#           so we can be sure buffer is not modified in between.
 	warn "# Executing: $editor\n";
-	if (system($editor) == 0) {
+	if (system($editor) == 0 and defined $page) {
 		# Save source
-		$fh = $page->open_source('w');
+		my $fh = $page->open_source('w');
 		print $fh $file->read;
 		$fh->close;
 		$self->Reload;
@@ -2034,7 +2244,6 @@ sub RBIndex {
 	my $tree = $self->TreeView;
 	$tree->{_loaded} = 0;
 	$tree->load_index;
-	$self->Reload;
 }
 
 
@@ -2192,7 +2401,7 @@ sub About {
 		website => $Zim::WEBSITE,
 	);
 	$info{translator_credits} =~ s/^\n+//;
-	
+
 	if (Gtk2->CHECK_VERSION(2, 6, 0)) {
 		my $hook = sub {$self->link_clicked($_[1])};
 		Gtk2::AboutDialog->set_url_hook($hook);
@@ -2211,7 +2420,7 @@ sub About {
 		my $button = $self->new_button('gtk-help', '_More');
 		$dialog->add_action_widget($button, 'help');
 		$dialog->set_default_response('close');
-	
+
 		$dialog->vbox->add(
 			Gtk2::Image->new_from_file($Zim::ICON) );
 		my $text = $Zim::LONG_VERSION;
@@ -2220,7 +2429,7 @@ sub About {
 		$label->set_markup($text);
 		$label->set_justify('center');
 		$dialog->vbox->add($label);
-	
+
 		$dialog->show_all;
 		my $response = $dialog->run;
 		$dialog->destroy;
@@ -2292,14 +2501,14 @@ Returns new page name and update boolean.
 
 sub prompt_rename_page_dialog {
 	my ($self, $page) = @_;
-	
+
 	my ($dialog, $entries) = $self->new_prompt(
 		__('Rename page'), #. dialog title
 		['page'], {page =>
 			[__('Rename to'), 'page', $page] #. dialog label
-		}, 
+		},
 		'gtk-save', __('_Rename')  ); #. save button
-	
+
 	my ($entry) = @$entries;
 	$entry->select_region(length($1), -1) if $page =~ /^(.+:)/;
 
@@ -2308,7 +2517,7 @@ sub prompt_rename_page_dialog {
 	my $check1 = Gtk2::CheckButton->new(
 		__("_Update links in this page")); # check box
 	my $check2 = Gtk2::CheckButton->new(
-		__("_Update {number} pages linking here", number => $nlinks)); # check box
+		__n("_Update {number} page linking here", "_Update {number} pages linking here", number => $nlinks)); # check box
 	$check1->set_active(1);
 	if ($nlinks > 0) { $check2->set_active(1)    }
 	else             { $check2->set_sensitive(0) }
@@ -2316,7 +2525,7 @@ sub prompt_rename_page_dialog {
 	$check2->show;
 	$dialog->vbox->add($check1);
 	$dialog->vbox->add($check2);
-	
+
 	if ($dialog->run eq 'ok') { $page = $entry->get_text }
 	else                      { $page = undef            }
 	my $up1 = $check1->get_active;
