@@ -7,7 +7,7 @@ use Zim::Template;
 
 our @ISA = qw/Zim::GUI::Component/;
 
-our $VERSION = '0.24';
+our $VERSION = '0.27';
 
 our %DEFAULTS = (
 	latex => 
@@ -41,6 +41,19 @@ resolved relative to the current page.
 sub init {
 	my $self = shift;
 	$self->init_settings('EquationEditor Plugin', \%DEFAULTS);
+
+	# Test if the applications are available
+	my $null = File::Spec->devnull;
+	my ($latex, $dvipng) = @{$$self{settings}}{qw/latex dvipng/};
+	for ($latex, $dvipng) {
+		/^(\S+)/; # match base command
+		system("$1 -v > $null") == 0 and next;
+		
+		my $error = __('Can not find application "{name}"', name => $1); #. error when external application is not found
+		$self->error_dialog($error);
+		$$self{app}->unplug('EquationEditor');
+		die $error."\n";
+	}
 }
 
 sub show {
@@ -71,14 +84,10 @@ sub show {
 	$self->{image_window} = $win1;
 	$vbox->add($win1);
 	
-	my $win2 = Gtk2::ScrolledWindow->new;
-	$win2->set_policy('automatic', 'automatic');
-	$win2->set_shadow_type('in');
-	$vbox->add($win2);
-
-	my $text = Gtk2::TextView->new;
+	my ($win2, $text) = $self->new_textview;
+	$text->set_editable(1);
 	$self->{buffer} = $text->get_buffer;
-	$win2->add($text);
+	$vbox->add($win2);
 
 	my $hbox = Gtk2::HBox->new;
 	$dialog->vbox->pack_start($hbox, 0,1,0);
@@ -287,13 +296,9 @@ sub view_log {
 	);
 	$dialog->set_resizable(1);
 	$dialog->set_default_size(600, 300);
-	my $win = Gtk2::ScrolledWindow->new;
-	$win->set_policy('automatic', 'automatic');
+	my ($win, $text) = $self->new_textview(
+		''.file($$self{log_file})->read );
 	$dialog->vbox->add($win);
-	my $text = Gtk2::TextView->new;
-	$text->get_buffer->set_text( file($$self{log_file})->read || '');
-	$text->set_editable(0);
-	$win->add($text);
 	$dialog->show_all;
 	$dialog->run;
 	$dialog->destroy;
