@@ -6,7 +6,7 @@ use Gtk2;
 use Gtk2::SimpleList;
 use Zim::Utils;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 =head1 NAME
 
@@ -55,6 +55,10 @@ my %Labels = ( # setting => [label, tooltip]
 		__('Text editor'), #. pref. label
 		__("Application to edit text files"), #. pref. tooltip
 	],
+	diff_editor => [
+		__('Diff editor'), #. pref. label
+		__("Application show two text files side by side"), #. pref. tooltip
+	],
 	user_name => [
 		__('User name'), #. pref. label
 		__("Your name; this can be used in export templates"), #. pref. tooltip
@@ -83,6 +87,14 @@ my %Labels = ( # setting => [label, tooltip]
 		__('Auto-format entities'), #. pref. label
 		__("Use autoformatting to type special characters"), #. pref. tooltip
 	],
+	use_autoincr => [
+		__('Auto-increment numbered lists'), #. pref. label
+		__('Automatically increment items in a numbered list'), #. pref. tooltip
+	],
+	use_recurscheck => [
+		__('Check checkbox lists recursive'), #. pref. label
+		__('Checking a checkbox list item will also check any sub-items'), #. pref. tooltip
+	],
 	backsp_unindent => [
 		__('Use "Backspace" to un-indent'), #. pref. label
 		__("Use the \"Backspace\" key to un-indent bullet lists (Same as \"Shift-Tab\")"), #. pref. tooltip
@@ -163,6 +175,7 @@ sub show {
 		file_browser
 		email_client
 		text_editor
+		diff_editor
 	/;
 	my $table = Gtk2::Table->new(scalar(@settings), 2);
 	$table->set_row_spacings(5);
@@ -233,8 +246,10 @@ sub show {
 		use_camelcase
 		use_linkfiles
 		use_utf8_ent
+		use_autoincr
 		use_autoselect
 		backsp_unindent
+		use_recurscheck
 	/;
 	$table = Gtk2::Table->new(scalar(@settings), 1);
 	$table->set_row_spacings(5);
