@@ -1,11 +1,11 @@
 package Zim::GUI::SearchDialog;
 
 use strict;
-use Gtk2;
-use Gtk2::SimpleList;
 use Zim::Utils;
+use Zim::GUI::Component;
 
-our $VERSION = '0.24';
+our $VERSION = '0.27';
+our @ISA = qw/Zim::GUI::Component/;
 
 =head1 NAME
 
@@ -19,17 +19,6 @@ This module contains the search dialog for zim.
 
 =over 4
 
-=item C<new()>
-
-Simple constructor
-
-=cut
-
-sub new {
-	my ($class, %self) = @_;
-	bless \%self, $class;
-}
-
 =item C<show()>
 
 =cut
@@ -88,7 +77,7 @@ sub show {
 	$list->get_column(0)->set_sort_column_id(0);
 	$list->get_column(1)->set_sort_column_id(1);
 	$list->get_model->set_sort_column_id(1 => 'descending');
-	$list->signal_connect(button_release_event => \&on_button_release_event);
+	$self->set_treeview_single_click($list);
 	$swindow->add($list);
 	
 	$find_button->signal_connect(clicked => sub {
@@ -124,6 +113,7 @@ sub show {
 		my ($name) = @{$list->{data}[$i]};
 		$self->{app}->present;
 		$self->{app}->link_clicked($name);
+		$self->{app}->PageView->Find($string_entry->get_text);
 	} );
 
 	$dialog->signal_connect(response => sub {
@@ -133,8 +123,9 @@ sub show {
 			$self->{app}->ShowHelp(':usage:searching');
 			return;
 		}
-		
-		$self->hide;
+		else {
+			$self->hide;
+		}
 	} );
 
 	if (length $query) {
@@ -171,22 +162,6 @@ sub search {
 	$self->show(@_);
 }
 
-sub on_button_release_event {
-	my ($slist, $event) = @_;
-	return 0 if $event->type ne 'button-release';
-	
-	my ($x, $y) = $event->get_coords;
-	my ($path, $column) = $slist->get_path_at_pos($x, $y);
-	return 0 unless $path;
-	
-	if ($event->button == 1) { # single-click navigation
-		return 0 unless $slist->get_selection->path_is_selected($path);
-		$slist->row_activated($path, $column);
-	}
-	
-	return 0;
-}
-
 =item C<edit_query()>
 
 Opens the "Edit query" dialog.
@@ -242,10 +217,9 @@ sub edit_query {
 	$hbox->add($add_button);
 	$entry->signal_connect(activate => sub{ $add_button->clicked });
 
-	my $textview = Gtk2::TextView->new;
 	$query =~ s/(\s)(AND|OR|NOT|&&?|\|\|?|\!)\s/$1$2\n/g;
-	$textview->get_buffer->set_text($query);
-	$dialog->vbox->add($textview);
+	my ($scroll, $textview) = $self->new_textview($query);
+	$dialog->vbox->add($scroll);
 
 	$add_button->signal_connect(clicked => sub {
 			my $opp = _get_active_text($opp_combo);
