@@ -5,7 +5,7 @@ use Carp;
 use Zim::Page;
 use Zim::Utils;
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 =head1 NAME
 
@@ -91,7 +91,11 @@ The default does nothing.
 
 =cut
 
-sub get_page { die 'BUG: not implemented: '.ref($_[0])."->get_page()\n" }
+sub get_page {
+	my @c = caller;
+	die "BUG: ".ref($_[0])."->get_page() not implemented\n" .
+	    "     called from: @c\n"
+}
 
 =item C<resolve_page(LINK, PAGE, NO_DEFAULT)>
 
@@ -142,6 +146,8 @@ REF contains parts of the pagename we use as base for a relative lookup.
 Try to match the first part of NAME in the path defined by REF.
 If REF is undefined, just start from ":".
 
+Should return a case sensitive page name.
+
 =cut
 
 sub resolve_name { #warn "resolve_name(@_)\n";
@@ -172,7 +178,9 @@ sub resolve_name { #warn "resolve_name(@_)\n";
 }
 
 sub resolve_case {
-	die 'BUG: not implemented: '.ref($_[0])."->resolve_case()\n";
+	my @c = caller;
+	die "BUG: ".ref($_[0])."->resolve_case() not implemented\n" .
+	    "     called from: @c\n"
 }
 
 =item C<copy_page(SOURCE, TARGET)>
@@ -223,7 +231,11 @@ The default method fails by exception.
 
 =cut
 
-sub delete_page { die 'BUG: not implemented: '.ref($_[0])."->delete_page()\n" }
+sub delete_page { 
+	my @c = caller;
+	die "BUG: ".ref($_[0])."->delete_page() not implemented\n" .
+	    "     called from: @c\n"
+}
 
 =item C<search()>
 
@@ -403,7 +415,8 @@ sub resolve_file {
 		else { $path = $p }
 	}
 
-	for (grep defined($_), $doc_dir, $doc_dir_root, $doc_root) {
+	my $vcs = $$self{parent}{vcs};
+	for (grep defined($_), $doc_dir, $doc_dir_root, $doc_root, $vcs) {
 		# Check whether we can nest this file under one of our dirs
 		# this is needed in case dirs are under version control etc.
 		my $rel = Zim::FS->rel_path($path, $_);
@@ -513,24 +526,26 @@ sub root {
 
 =item C<check_dir()>
 
-Checks for a "dir" attribute.
-Check if parent has a dir and derives from that.
-Dies on failure.
+Checks for a "dir" attribute, else check if parent has a dir and derives
+from that. Dies on failure.
+Used when initializing store sub-classes that are dir based.
 
 =cut
 
 sub check_dir {
 	my $self = shift;
-	return if ref $$self{dir};
+	return if ref $$self{dir}; # already an object
 
 	if (defined $$self{dir}) {
-		# check dir relative to parent
-		my $rel_path = $$self{parent}{dir}
-			? Zim::FS->rel_path($$self{dir}, $$self{parent}{dir})
+		# check if we can get dir relative to parent
+		my $dir = Zim::FS->abs_path($$self{dir});
+		my $parent = $$self{parent}{dir};
+		my $rel = $parent
+			? Zim::FS->rel_path($dir, $parent) 
 			: undef ;
-		$$self{dir} = defined($rel_path)
-			? $$self{parent}{dir}->subdir($rel_path)
-			: dir( Zim::FS->abs_path($$self{dir}) );
+		$$self{dir} = defined($rel)
+			? $parent->subdir($rel)
+			: dir($dir) ;
 	}
 	else {
 		# no dir given, find one based on namespace
@@ -540,7 +555,35 @@ sub check_dir {
 		$$self{dir} = $$self{parent}{dir}->resolve_dir(undef, @parts);
 	}
 	
-	warn "## '$$self{namespace}' using dir: $$self{dir} (".ref($$self{dir}).")\n";
+	warn "## '$$self{namespace}' using dir: $$self{dir}\n";
+}
+
+=item C<check_file()>
+
+Check if a "file" attribute is set and make sure "dir" is set based on that.
+Used when initializing store sub-classes that are file based.
+
+=cut
+
+sub check_file {
+	my $self = shift;
+	die ref($self)." needs a file to initialize\n"
+		unless defined $$self{file};
+
+	unless (ref $$self{file}) {
+		# If file is not an object, see if we can get it
+		# relative to the parent dir
+		my ($file, $dir) = ($$self{file}, $$self{parent}{dir});
+		$file = Zim::FS->abs_path($file, $dir);
+		my $rel = defined($dir)
+			? Zim::FS->rel_path($file, $dir)
+			: undef ;
+		$$self{file} = defined($rel) ? $dir->file($rel) : file($file) ;
+	}
+
+	$$self{dir} = $$self{file}->dir;
+		# Used for e.g. for the document dir etc.
+		# so needs to be defined.
 }
 
 =item C<wipe_array(REF)>
