@@ -4,7 +4,7 @@ use strict;
 use File::BaseDir 0.03 qw/data_files/;
 use Zim::FS;
 
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 eval 'use Zim::OS::Win32' if $^O eq 'MSWin32';
 die $@ if $@;
@@ -12,8 +12,8 @@ die $@ if $@;
 our @ISA = ($^O eq 'MSWin32') ? ('Zim::Utils::Win32')
                               : ('Zim::Utils::Unix' ) ;
 
-our %Translation;
-our @export = qw/__ __actions file dir uri buffer/;
+our ($Plural, %Translation);
+our @export = qw/__ __n __actions file dir uri buffer/;
 
 =head1 NAME
 
@@ -32,23 +32,32 @@ and C<buffer()> are exported.
 
 =over 4
 
+=cut
+
+sub import {
+	shift; # class
+	my ($caller) = caller;
+	no strict 'refs';
+	*{$caller.'::'.$_} = \&{$_} for @_ ? (@_) : (@export);
+}
+
 =item C<file(@PATH)>
 
-Returns a new C<Zim::FS::File> object.
+Returns a new C<Zim::FS::File> object, see L<Zim::FS>.
 
 =item C<dir(@PATH)>
 
-Returns a new C<Zim::FS::Dir> object.
+Returns a new C<Zim::FS::Dir> object, see L<Zim::FS>.
 
 =item C<uri(@URI)>
 
-Returns a new C<Zim::FS::URI> object.
+Returns a new C<Zim::FS::URI> object, see L<Zim::FS>.
 
 =item C<buffer(\$STRING)>
 
 =item C<buffer(@STRING)>
 
-Returns a new C<Zim::FS::Buffer> object.
+Returns a new C<Zim::FS::Buffer> object, see L<Zim::FS>.
 
 =cut
 
@@ -73,6 +82,7 @@ sub buffer {
 =item C<find_translation()>
 
 Tries to load messages for the current locale.
+Called automatically when this module is loaded.
 
 =cut
 
@@ -84,22 +94,29 @@ sub find_translation {
 	}
 	return () unless $file;
 	warn "# Loading translation from: $file\n";
-	eval { %Translation = %{do $file} };
+	eval {
+		# file optionally defines a sub for plural forms
+		# in any case contains hash ref with strings (and plural arrays)
+		my @arg = do $file;
+		$Plural = shift @arg if ref($arg[0]) eq 'CODE';
+		%Translation = %{shift @arg};
+	};
+	$Plural ||= sub { my $n = shift; $n != 1 } ;
 	warn $@ if $@;
 	#use Data::Dumper; warn Dumper \%Translation;
 }
 
-sub import {
-	my ($caller) = caller;
-	no strict 'refs';
-	*{$caller.'::'.$_} = \&{$_} for @export;
-}
-
-=item C<__(STRING, PARAM => VALUE, ...)>
+=item C<< __(STRING, PARAM => VALUE, ...) >>
 
 Return a translation for STRING. Parameters can be placed in
 the string using C<{PARAM}> syntax.
 
+=item C<< __n(STRING, PLURAL_STRING, number => N, PARAM => VALUE, ...) >>
+
+Like C<__()> but deals with plural forms. The parameter C<{number}>
+determines which plural is used (yes translations can have more than
+one plural form ...).
+
 =item C<__actions(BLOCK)>
 
 Wrapper for C<__()> that can be used to translate actions.
@@ -115,11 +132,37 @@ sub __ {
 	return $string;
 }
 
+sub __n {
+	my ($string, $plural, %arg) = @_;
+	my $trans = $Translation{$string};
+	if (! defined $trans) {
+		# default, use english:
+		# nplurals=2; plural=n != 1;
+		$trans = ($arg{number} == 1) ? $string : $plural ;
+	}
+	elsif (ref $trans) {
+		# use plural as supplied by template
+		my $i = $Plural->($arg{number});
+		$i = $#$trans if $i > $#$trans;
+		$trans = $$trans[$i];
+	}
+	# else we had only single tranlation string
+	$trans =~ s/\{(\w+)\}/$arg{$1}/g;
+	return $trans;
+}
+
 sub __actions {
 	my $block = shift;
 	my $new;
 	for my $l (split "\n", $block) {
+		# The "is_menu" boolean is needed because autovivicating
+		# tooltips for menu labels somehow invokes even more dark magic
+		# on win32 this causes the main TextView to stop recieving
+		# input ! see lp bug #252005 which was introduced by tooltip
+		# fix for lp #226971 below :S
+		next unless $l =~ /\S/;
 		my @col = split /\t+/, $l;
+		my $is_menu = (scalar(@col) < 4);
 		$col[$_] ||= '' for 0 .. 4;
 		my $key = __(qq{$col[2]|$col[4]});
 			# HACK: avoid indexing by xgettext by not using quotes
@@ -131,10 +174,12 @@ sub __actions {
 			# string fixes this, but it works. However just a 
 			# space is not enoug. Must be dark magic ...
 			$col[4] = $col[2];
-			$col[4] =~ s/_/ /;
+			$col[4] =~ s/_//; # remove accelerator
 		}
+		@col = @col[0..2] if $is_menu;
 		$new .= join("\t", @col)."\n";
 	}
+	#warn "ACTIONS >>\n$new<<\n\n";
 	return $new;
 }
 
@@ -219,6 +264,7 @@ Run background process (fork + exec).
 
 sub run {
 	my ($self, @args) = @_;
+	@args = grep defined($_), @args;
 	warn "# Executing: @args\n";
 	unless (fork) { # child process
 		exec @args;
