@@ -1,23 +1,40 @@
+# translation of zim-cs.po to
+# Vlastimil Ott <vlastimil@e-ott.info>, 2007.
+# translation of zim.po to
+# 
+# TRANSLATORS:
+# Vlastimil Ott (cs)
+# Vlastimil Ott (cs)
+# 
 # Project-Id-Version: zim-cs
 # Report-Msgid-Bugs-To: 
-# POT-Creation-Date: 2008-05-08 00:12+0800
+# POT-Creation-Date: 2008-10-27 21:09+0100
 # PO-Revision-Date: 2008-03-17 18:33+0000
 # Last-Translator: Vlastimil Ott <linux@e-ott.info>
 # Language-Team: <cs@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
-# X-Launchpad-Export-Date: 2008-05-19 15:32+0000
+# Plural-Forms: nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
+# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
 
+# Subroutine to determine plural:
+sub {my $n = shift; ($n==1) ? 0 : ($n>=2 && $n<=4) ? 1 : 2},
+
+# Hash with translation strings:
 {
   '%a %b %e %Y' => '%a %b %e %Y',
   '<b>Delete page</b>
 
 Are you sure you want to delete
 page \'{name}\' ?' => '',
+  '<b>Enable Version Control</b>
+
+Version control is currently not enabled for this notebook.
+Do you want to enable it ?' => '',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -27,6 +44,12 @@ does not exist, do you want to create it now?' => '',
 The page \'{name}\'
 already exists.
 Do you want to overwrite it?' => '',
+  '<b>Restore page to saved version?</b>
+
+Do you want to restore page: {page}
+to saved version: {version} ?
+
+All changes since the last saved version will be lost !' => '',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -36,6 +59,7 @@ namespaces per month.
 Do you want to upgrade this notebook to the new layout?
 ' => '',
   'Add \'tearoff\' strips to the menus' => 'Připojí k nabídkám odtrhávací proužky',
+  'Application show two text files side by side' => '',
   'Application to compose email' => 'Aplikace pro odesílání e-mailů',
   'Application to edit text files' => 'Aplikace pro editování textových souborů',
   'Application to open directories' => 'Aplikace pro otevírání adresářů',
@@ -43,33 +67,57 @@ Do you want to upgrade this notebook to the new layout?
   'Attach _File|Attach external file' => 'Připo_jit soubor|Připojit externí soubor',
   'Attach external files' => '',
   'Auto-format entities' => 'Automaticky formátovat entity',
+  'Auto-increment numbered lists' => '',
   'Auto-link CamelCase' => 'Automaticky odkazovat na SpojenáSlova',
   'Auto-link files' => 'Automaticky odkazovat na soubory',
+  'Auto-save version on close' => '',
   'Auto-select words' => 'Automaticky vybírat slova',
+  'Automatically increment items in a numbered list' => '',
   'Automatically link file names when you type' => 'Automaticky vytváří odkazy na soubory, jakmile napíšete jejich název',
   'Automaticly link CamelCase words when you type' => 'Automaticky vytváří odkazy ze SpojenýchSlov, jakmile je napíšete',
   'Automaticly select the current word when you toggle the format' => 'Automaticky vybere aktuální slovo, pokud měníte formát',
   'Bold' => 'Tučné',
   'Calen_dar|Show calendar' => '_Kalendář|Zobrazit kalendář',
   'Calendar' => 'Kalendář',
+  'Can not find application "bzr"' => '',
+  'Can not find application "{name}"' => '',
+  'Can not save a version without comment' => '',
   'Can not save to page: {name}' => 'Nelze uložit stránku {name}',
   'Can\'t find {url}' => 'Nelze najít {url}',
   'Cha_nge' => 'Z_měnit',
   'Chars' => 'Znaků',
   'Check _spelling|Spell check' => '_Kontrola překlepů|Kontrola překlepů',
+  'Check checkbox lists recursive' => '',
+  'Checking a checkbox list item will also check any sub-items' => '',
   'Choose {app_type}' => 'Vybrat {app_type}',
+  'Co_mpare Page...' => '',
   'Command' => 'Příkaz',
+  'Comment' => '',
+  'Compare this version with' => '',
   'Copy Email Address' => 'Kopírovat e-mailovou adresu',
   'Copy Location|Copy location' => 'Kopírovat umístění|Kopírovat umístění',
   'Copy _Link' => 'Kopírovat _odkaz',
   'Could not delete page: {name}' => 'Stránku {name} nelze smazat',
+  'Could not get annotated source for page {page}' => '',
+  'Could not get changes for page: {page}' => '',
+  'Could not get changes for this notebook' => '',
+  'Could not get file for page: {page}' => '',
+  'Could not get versions to compare' => '',
+  'Could not initialize version control' => '',
   'Could not load page: {name}' => 'Nelze načíst stránku {name}',
   'Could not rename {from} to {to}' => 'Nelze přejmenovat z {from} na {to}',
   'Could not save page' => 'Stránku nelze uložit',
+  'Could not save version' => '',
   'Creating a new link directly opens the page' => 'Vytvoření nového odkazu přímo otevře stránku',
+  'Creation Date' => '',
   'Cu_t|Cut' => 'V_yjmout|Vyjmout',
+  'Current' => '',
   'Customise' => 'Přizpůsobit',
   'Date' => 'Datum',
+  'Default notebook' => '',
+  'Details' => '',
+  'Diff Editor' => '',
+  'Diff editor' => '',
   'Directory' => 'Adresář',
   'Document Root' => 'Kořen dokumentu',
   'E_quation...|Insert equation' => '',
@@ -89,7 +137,11 @@ Do you want to upgrade this notebook to the new layout?
   'Expand side pane' => 'Rozbalit boční panel',
   'Export page' => 'Exportovat stránku',
   'Exporting page {number}' => 'Exportuji stránku {number}',
+  'Failed to cleanup SVN working copy.' => '',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => '',
   'Failed to load plugin: {name}' => 'Nelze načíst zásuvný modul {name}',
+  'Failed update working copy.' => '',
   'File browser' => 'Správce souborů',
   'File is not a text file: {file}' => 'Soubor {file} není textový soubor',
   'Filter' => 'Filtr',
@@ -117,7 +169,10 @@ Do you want to upgrade this notebook to the new layout?
   'Height' => 'Výška',
   'Home Page' => 'Domovská stránka',
   'Icon' => 'Ikona',
+  'Id' => '',
+  'Include all open checkboxes' => '',
   'Index page' => 'Stránka s indexem',
+  'Initial version' => '',
   'Insert Date' => 'Vložit datum',
   'Insert Image' => 'Vložit obrázek',
   'Insert Link' => 'Vložit odkaz',
@@ -130,12 +185,15 @@ Do you want to upgrade this notebook to the new layout?
   'Links to' => 'Odkazuje na',
   'Match c_ase' => 'Rozlišovat ve_likost',
   'Media' => 'Média',
+  'Modification Date' => '',
   'Name' => 'Název',
   'New notebook' => 'Nové úložiště',
   'New page' => 'Nová stránka',
   'No such directory: {name}' => 'Adresář {name} neexistuje',
+  'No such file or directory: {name}' => '',
   'No such file: {file}' => 'Soubor {file} neexistuje',
   'No such notebook: {name}' => 'Úložiště {name} neexistuje',
+  'No such page: {page}' => '',
   'No such plugin: {name}' => 'Zásuvný modul {name} neexistuje',
   'Normal' => 'Normální',
   'Not Now' => '',
@@ -158,14 +216,20 @@ ji automaticky vytvoří.',
   'Page Editable|Page editable' => '',
   'Page name' => 'Název stránky',
   'Pages' => 'Stránky',
-  'Please enter a name to save' => '',
+  'Password' => '',
+  'Please enter a comment for this version' => '',
+  'Please enter a name to save a copy of page: {page}' => '',
   'Please enter a {app_type}' => 'Zadejte prosím {app_type}',
+  'Please give a page first' => '',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Zadejte prosím adresář, kde budou uloženy vytvořené stránky.
 Nové úložiště by mělo mít vlastní prázdný adresář.
 Například adresář "Poznámky" ve vašem domovském adresáři.',
-  'Please select a default notebook here' => 'Zde prosím vyberte defaultní úložiště',
+  'Please provide the password for
+{path}' => '',
+  'Please select a notebook first' => '',
+  'Please select a version first' => '',
   'Plugin already loaded: {name}' => 'Zásuvný modul {name} je již načtený',
   'Plugins' => 'Moduly',
   'Pr_eferences|Preferences dialog' => '_Nastavení|Dialog s nastavením',
@@ -182,20 +246,23 @@ Například adresář "Poznámky" ve vašem domovském adresáři.',
   'Rename to' => 'Přejmenovat na',
   'Replace _all' => 'Nahradit _vše',
   'Replace with' => 'Nahradit výrazem',
-  'S_ave A Copy...|Save a copy' => 'Uložit _kopii...|Uložit kopii',
+  'SVN cleanup|Cleanup SVN working copy' => '',
+  'SVN commit|Commit notebook to SVN repository' => '',
+  'SVN update|Update notebook from SVN repository' => '',
+  'S_ave Version...|Save Version' => '',
   'Save Copy' => 'Uložit kopii',
+  'Save version' => '',
   'Scanning tree ...' => 'Prohledávám strom...',
   'Search' => 'Hledat',
   'Search _Backlinks...|Search Back links' => 'Hledat _zpětné odkazy...|Hledat zpětné odkazy',
   'Select File' => 'Vybrat soubor',
   'Select Folder' => '',
   'Send To...' => 'Odeslat...',
-  'Set _Default' => 'Nastavit _defaultní',
-  'Set default notebook' => 'Nastavit defaultní úložiště',
   'Show cursor for read-only' => 'Zobrazovat kurzor v režimu jen pro čtení',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Zobrazí kurzor, i když stránku nelze editovat. Je to praktické při prohlížení jen pomocí klávesnice.',
   'Slow file system' => 'Pomalý souborový systém',
   'Source' => 'Zdroj',
+  'Source Format' => '',
   'Start the side pane with the whole tree expanded.' => 'Při spuštění je strom v bočním panelu rozbalený.',
   'Stri_ke|Strike' => 'Proš_krtnuté|Proškrtnuté',
   'Strike' => 'Proškrtnuté',
@@ -215,7 +282,11 @@ is missing. Can not edit equation.' => '',
 404' => '',
   'This page does not have a document folder' => '',
   'This page does not have a source' => 'Tato stránka nemá zdroj',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => '',
   'To_day|Today' => '_Dnešek|Dnešní den',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Podtržené',
   'Updating links' => 'Aktualizuji odkazy',
   'Updating links in {name}' => 'Aktualizuji odkazy v {name}',
@@ -228,8 +299,11 @@ is missing. Can not edit equation.' => '',
   'Use the "Backspace" key to un-indent bullet lists (Same as "Shift-Tab")' => 'Klávesa "Backspace" zruší odsazení položek seznamu (stejně jako "Shift-Tab")',
   'Use the "Ctrl-Space" key combo to switch focus between text and side pane. If disabled you can still use "Alt-Space".' => 'Klávesou "Ctrl-Space" se lze přepínat mezi textem a bočním panelem. Pokud je volba zakázána, můžete použít "Alt-Space".',
   'Use the "Enter" key to follow links. If disabled you still can use "Alt-Enter"' => 'Klávesu "Enter" použijte pro odskok na cíl odkazu. Pokud je tato volba zakázána, můžete použít "Alt-Enter"',
+  'User' => '',
   'User name' => 'Uživatelské jméno',
   'Verbatim' => 'Strojopis',
+  'Versions' => '',
+  'View _Annotated...' => '',
   'View _Log' => 'Zobrazit _záznam',
   'Web browser' => 'Webový prohlížeč',
   'Whole _word' => '_Celá slova',
@@ -237,6 +311,8 @@ is missing. Can not edit equation.' => '',
   'Word Count' => 'Počet slov',
   'Words' => 'Slov',
   'You can add rules to your search query below' => 'Můžete přidat pravidla pro uvedený vyhledávací dotaz.',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '',
   'You have no {app_type} configured' => 'Není nastavena {app_type}',
   'You need to restart the application
 for plugin changes to take effect.' => 'Program je nutné znovu spustit, 
@@ -252,11 +328,13 @@ aby se změny v modulech projevily.',
   '_Child|Go to child page' => 'P_otomek|Přejít na podřízenou stránku',
   '_Close|Close window' => '_Zavřít|Zavřít okno',
   '_Contents|Help contents' => '_Obsah|Obsah nápovědy',
+  '_Copy Page...|Copy page' => '',
   '_Copy|Copy' => '_Kopírovat|Kopírovat',
   '_Date and Time...|Insert date' => '_Datum a čas...|Vložit datum',
   '_Delete Page|Delete page' => '_Smazat stránku|Smazat stránku',
   '_Delete|Delete' => '_Smazat|Smazat',
   '_Discard changes' => 'Za_hodit změny',
+  '_Edit' => '',
   '_Edit Equation' => '_Upravit rovnici',
   '_Edit Link' => '_Upravit odkaz',
   '_Edit Link...|Edit link' => '_Upravit odkaz|Upravit odkaz',
@@ -286,10 +364,12 @@ aby se změny v modulech projevily.',
   '_Next' => '_Další',
   '_Next in index|Go to next page' => '',
   '_Normal|Normal' => '_Normální|Normální',
+  '_Notebook Changes...' => '',
   '_Open Another Notebook...|Open notebook' => '_Otevřít jiné úložiště|Otevřít úložiště',
   '_Open link' => '_Otevřít odkaz',
   '_Overwrite' => '_Přepsat',
   '_Page' => '_Stránku',
+  '_Page Changes...' => '',
   '_Parent|Go to parent page' => '_Rodič|Přejít na rodičovskou stránku',
   '_Paste|Paste' => '_Vložit|Vložit',
   '_Preview' => '_Náhled',
@@ -305,6 +385,7 @@ aby se změny v modulech projevily.',
   '_Replace' => '_Nahradit',
   '_Replace...|Find and Replace' => 'Za_měnit...|Najít a zaměnit',
   '_Reset' => '_Původní hodnoty',
+  '_Restore Version...' => '',
   '_Save Copy' => 'Uložit _kopii',
   '_Save a copy...' => 'Uložit _kopii...',
   '_Save|Save page' => '_Uložit|Uložit stránku',
@@ -320,15 +401,22 @@ aby se změny v modulech projevily.',
   '_Underline|Underline' => '_Podtržené|Podtržené',
   '_Undo|Undo' => '_Zpět|Zpět',
   '_Update links in this page' => '_Aktualizovat odkazy na této stránce',
-  '_Update {number} pages linking here' => 'Aktualizovat {number} _stránek, které sem odkazují',
+  '_Update {number} page linking here' => [
+    '',
+    ''
+  ],
   '_Verbatim|Verbatim' => '_Strojopis|Strojopis',
+  '_Versions...|Versions' => '',
   '_View|' => '_Zobrazit|',
   '_Word Count|Word count' => 'Počet _slov|Počet slov',
   'other...' => 'jiná...',
-  'translator-credits' => 'Launchpad Contributions:
-  Vlastimil Ott https://launchpad.net/~vlastimil
-  Vlastimil Ott https://launchpad.net/~vlastimil-e-ott',
   '{name}_(Copy)' => '',
-  '{number} _Back links' => '{number} zpětných od_kazů',
-  '{total} items total' => 'Celkem položek: {total}'
+  '{number} _Back link' => [
+    '',
+    ''
+  ],
+  '{number} item total' => [
+    '',
+    ''
+  ]
 };
