@@ -1,17 +1,32 @@
+# Danish translation for zim
+# Copyright (c) 2008 Rosetta Contributors and Canonical Ltd 2008
+# This file is distributed under the same license as the zim package.
+# FIRST AUTHOR <EMAIL@ADDRESS>, 2008.
+# 
+# 
+# TRANSLATORS:
+# Frederik 'Freso' S. Olesen (da)
+# Jeppe Toustrup (da)
+# 
 # Project-Id-Version: zim
 # Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>
-# POT-Creation-Date: 2008-05-08 00:12+0800
-# PO-Revision-Date: 2008-05-12 08:01+0000
-# Last-Translator: Frederik 'Freso' S. Olesen <Unknown>
+# POT-Creation-Date: 2008-10-27 21:09+0100
+# PO-Revision-Date: 2008-09-30 11:39+0000
+# Last-Translator: Peter Skov <Unknown>
 # Language-Team: Danish <da@li.org>
 # MIME-Version: 1.0
 # Content-Type: text/plain; charset=UTF-8
 # Content-Transfer-Encoding: 8bit
-# X-Launchpad-Export-Date: 2008-05-19 15:32+0000
+# Plural-Forms: nplurals=2; plural=n != 1;
+# X-Launchpad-Export-Date: 2008-11-09 09:04+0000
 # X-Generator: Launchpad (build Unknown)
 
 use utf8;
 
+# Subroutine to determine plural:
+sub {my $n = shift; $n != 1},
+
+# Hash with translation strings:
 {
   '%a %b %e %Y' => '%a den %b. %e %Y',
   '<b>Delete page</b>
@@ -21,6 +36,13 @@ page \'{name}\' ?' => '<b>Slet side</b>
 
 Er du sikker på at du vil slette
 siden "{name}"?',
+  '<b>Enable Version Control</b>
+
+Version control is currently not enabled for this notebook.
+Do you want to enable it ?' => '<b>Aktivér versions kontrol</b>
+
+Versions kontrol er ikke aktiveret for denne notesblok lige nu.
+Ønsker du at aktivere det?',
   '<b>Folder does not exist.</b>
 
 The folder: {path}
@@ -37,6 +59,12 @@ Do you want to overwrite it?' => '<b>Siden eksisterer allerede</b>
 Siden "{name}"
 eksisterer allerede.
 Ønsker du at overskrive den?',
+  '<b>Restore page to saved version?</b>
+
+Do you want to restore page: {page}
+to saved version: {version} ?
+
+All changes since the last saved version will be lost !' => '',
   '<b>Upgrade calendar pages to 0.24 format?</b>
 
 This notebook contains pages for dates using the format yyyy_mm_dd.
@@ -53,6 +81,7 @@ opretter navnerum for hver måned.
 Ønsker du at opgradere denne notesblok til det nye format?
 ',
   'Add \'tearoff\' strips to the menus' => 'Tilføj afrivningsstreger til menuerne',
+  'Application show two text files side by side' => 'Et program til at sammelinge to tekstfiler side om side',
   'Application to compose email' => 'Program til at sende post',
   'Application to edit text files' => 'Program til at redigere tekstfiler',
   'Application to open directories' => 'Program til at åbne mapper',
@@ -60,33 +89,57 @@ opretter navnerum for hver måned.
   'Attach _File|Attach external file' => '_Vedhæft fil|Vedhæft en ekstern fil til notesblokken',
   'Attach external files' => 'Vedhæft eksterne filer',
   'Auto-format entities' => 'Auto-formatér specialtegn',
+  'Auto-increment numbered lists' => 'Øg automatisk nummerede lister',
   'Auto-link CamelCase' => 'Auto-henvis CamelCase',
   'Auto-link files' => 'Auto-henvis filer',
+  'Auto-save version on close' => 'Gem automatisk version ved lukning',
   'Auto-select words' => 'Markér automatisk ord',
+  'Automatically increment items in a numbered list' => 'Læg automatisk til nummeret i en nummereret liste',
   'Automatically link file names when you type' => 'Opret automatisk henvisninger til filer når du skriver',
   'Automaticly link CamelCase words when you type' => 'Henvis automatisk CamelCase-ord når du skriver',
   'Automaticly select the current word when you toggle the format' => 'Markér automatisk det aktuelle ord når du ændrer formatet',
   'Bold' => 'Fed',
   'Calen_dar|Show calendar' => '_Kalender|Vis kalender',
   'Calendar' => 'Kalender',
-  'Can not save to page: {name}' => 'Siden "{name}" kan ikke gemmes til',
+  'Can not find application "bzr"' => '',
+  'Can not find application "{name}"' => '',
+  'Can not save a version without comment' => 'Det er ikke muligt at gemme uden en kommentar',
+  'Can not save to page: {name}' => 'Siden "{name}" kan ikke gemmes',
   'Can\'t find {url}' => 'Adressen "{url}" kunne ikke findes',
   'Cha_nge' => '_Redigér',
   'Chars' => 'Tegn',
   'Check _spelling|Spell check' => 'Kontrollér stavemåder|Start kontrol af stavemåder',
+  'Check checkbox lists recursive' => '',
+  'Checking a checkbox list item will also check any sub-items' => '',
   'Choose {app_type}' => 'Vælg {app_type}',
+  'Co_mpare Page...' => 'S_ammeling side',
   'Command' => 'Kommando',
+  'Comment' => '',
+  'Compare this version with' => 'Sammeling denne version med',
   'Copy Email Address' => 'Kopiér _post adresse',
   'Copy Location|Copy location' => 'Kopiér _placering|Kopiér adressen til den aktive side',
   'Copy _Link' => 'Kopiér _henvisning',
   'Could not delete page: {name}' => 'Siden "{name}" kunne ikke slettes',
+  'Could not get annotated source for page {page}' => 'Det var ikke muligt at få en annoteret kilde for siden: {page}',
+  'Could not get changes for page: {page}' => 'Det var ikke muligt at få ændringerne for siden: {page}',
+  'Could not get changes for this notebook' => '',
+  'Could not get file for page: {page}' => 'Det var ikke muligt at få filen for siden: {page}',
+  'Could not get versions to compare' => 'Det var ikke muligt at få versionerne til sammelinging',
+  'Could not initialize version control' => 'Det var ikke muligt at starte versions kontrollen',
   'Could not load page: {name}' => 'Siden "{name}" kunne ikke indlæses',
-  'Could not rename {from} to {to}' => 'Det var ikke muligt at omdøbe fra "{from}" til "{to}"',
+  'Could not rename {from} to {to}' => 'Det var ikke muligt at omdøbe fra {from} til {to}',
   'Could not save page' => 'Siden kunne ikke gemmes',
+  'Could not save version' => 'Det var ikke muligt at gennem versionen',
   'Creating a new link directly opens the page' => 'Oprettelse af en ny henvisning åbner automatisk den nye side',
+  'Creation Date' => 'Oprettelsesdato',
   'Cu_t|Cut' => '_Klip|Klip teksten til udklipsholderen',
+  'Current' => 'Nuværende',
   'Customise' => 'Tilpas',
   'Date' => 'Dato',
+  'Default notebook' => 'Standard notesblok',
+  'Details' => 'Detaljer',
+  'Diff Editor' => 'Diff program',
+  'Diff editor' => 'Diff program',
   'Directory' => 'Mappe',
   'Document Root' => 'Dokumentrod',
   'E_quation...|Insert equation' => '_Ligning...|Indsæt en ligning',
@@ -106,7 +159,11 @@ opretter navnerum for hver måned.
   'Expand side pane' => 'Udfold sidepanelet',
   'Export page' => 'Eksportér side',
   'Exporting page {number}' => 'Eksporterer side {number}',
+  'Failed to cleanup SVN working copy.' => '',
+  'Failed to load SVN plugin,
+do you have subversion utils installed?' => '',
   'Failed to load plugin: {name}' => 'Udvidelsesmodulet "{name}" kunne ikke indlæses',
+  'Failed update working copy.' => '',
   'File browser' => 'Filvælger',
   'File is not a text file: {file}' => 'Filen "{file}" er ikke en tekstfil',
   'Filter' => 'Filter',
@@ -134,7 +191,10 @@ opretter navnerum for hver måned.
   'Height' => 'Højde',
   'Home Page' => 'Hjemmeside',
   'Icon' => 'Ikon',
+  'Id' => 'Id',
+  'Include all open checkboxes' => '',
   'Index page' => 'Indeksside',
+  'Initial version' => 'Første version',
   'Insert Date' => 'Indsæt dato',
   'Insert Image' => 'Indsæt billede',
   'Insert Link' => 'Indsæt henvisning',
@@ -147,12 +207,15 @@ opretter navnerum for hver måned.
   'Links to' => 'Henviser til',
   'Match c_ase' => '_Versalfølsom',
   'Media' => 'Medie',
+  'Modification Date' => 'Ændringsdato',
   'Name' => 'Navn',
   'New notebook' => 'Ny notesblok',
   'New page' => 'Ny side',
   'No such directory: {name}' => 'Mappen "{name}" findes ikke',
+  'No such file or directory: {name}' => '',
   'No such file: {file}' => 'Filen "{file}" kunne ikke findes',
   'No such notebook: {name}' => 'Notesbogen "{name}" findes ikke',
+  'No such page: {page}' => 'Siden findes ikke: {page}',
   'No such plugin: {name}' => 'Udvidelsesmodulet "{name}" findes ikke',
   'Normal' => 'Normal',
   'Not Now' => '_Ikke nu',
@@ -175,14 +238,20 @@ bliver der også automatisk oprettet en ny side.',
   'Page Editable|Page editable' => 'Side redigerbar|Ændre på hvorvidt der er mulighed for at redigere siden',
   'Page name' => 'Sidenavn',
   'Pages' => 'Sider',
-  'Please enter a name to save' => 'Indtast venligst det navn som skal gemmes',
+  'Password' => '',
+  'Please enter a comment for this version' => 'Indtast en kommentar til denne version',
+  'Please enter a name to save a copy of page: {page}' => 'Indtast venligst et navn for at gemme en kopi af siden: {page}',
   'Please enter a {app_type}' => 'Indtast venligst en {app_type}',
+  'Please give a page first' => 'Angiv venligst en side først',
   'Please give at least a directory to store your pages.
 For a new notebook this should be an empty directory.
 For example a "Notes" directory in your home dir.' => 'Angiv som minimum en mappe til at gemme dine sider i.
 Til en ny noteblok skal denne mappe være tom.
 For eksempel en mappe "Noter" i din hjemmemappe.',
-  'Please select a default notebook here' => 'Sæt venligst en standard notesblok her',
+  'Please provide the password for
+{path}' => '',
+  'Please select a notebook first' => 'Vælg venligst en notesblok først',
+  'Please select a version first' => 'Angiv venligst en version først',
   'Plugin already loaded: {name}' => 'Udvidelsesmodulet "{name}" er allerede indlæst',
   'Plugins' => 'Udvidelsesmoduler',
   'Pr_eferences|Preferences dialog' => 'I_ndstillinger|Justér indstillinger vedrørende Zim',
@@ -199,20 +268,23 @@ For eksempel en mappe "Noter" i din hjemmemappe.',
   'Rename to' => 'Omdøb til',
   'Replace _all' => 'Erstat _alt',
   'Replace with' => 'Erstat med',
-  'S_ave A Copy...|Save a copy' => 'Gem en _kopi...|Gem en kopi af siden',
+  'SVN cleanup|Cleanup SVN working copy' => '',
+  'SVN commit|Commit notebook to SVN repository' => '',
+  'SVN update|Update notebook from SVN repository' => '',
+  'S_ave Version...|Save Version' => 'Ge_m version...|Gem version',
   'Save Copy' => 'Gem kopi',
+  'Save version' => 'Gem version',
   'Scanning tree ...' => 'Skanner træ...',
   'Search' => 'Søg',
   'Search _Backlinks...|Search Back links' => 'Søg efter _referencer...|Søg efter sider der henviser til en given side',
   'Select File' => 'Vælg fil',
   'Select Folder' => 'Vælg mappe',
   'Send To...' => 'Send til...',
-  'Set _Default' => '_Sæt standard',
-  'Set default notebook' => 'Sæt standard notesblok',
   'Show cursor for read-only' => 'Vis markør i skrivebeskyttet tilstand',
   'Show the cursor even when you can not edit the page. This is useful for keyboard based browsing.' => 'Vis markøren selv om du ikke kan redigere siden. Dette kan bruges til tastaturbaseret læsning.',
   'Slow file system' => 'Langsomt filsystem',
   'Source' => 'Kildetekst',
+  'Source Format' => 'Kilde format',
   'Start the side pane with the whole tree expanded.' => 'Start sidepanelet med hele træet udfoldet',
   'Stri_ke|Strike' => '_Gennemstreget|Gennemstreget tekst',
   'Strike' => 'Gennemstreg',
@@ -226,7 +298,7 @@ For eksempel en mappe "Noter" i din hjemmemappe.',
   'Text editor' => 'Tekstbehandler',
   'The equation failed to compile. Do you want to save anyway?' => 'Ligningen kunne ikke oversættes. Ønsker du at gemme alligevel?',
   'The equation for image: {path}
-is missing. Can not edit equation.' => 'Ligningen for billedet "{path}"
+is missing. Can not edit equation.' => 'Ligningen for billedet {path}
 mangler. Det er ikke muligt at redigere ligningen.',
   'This notebook does not have a document root' => 'Denne notesblok har ikke en dokumentrod',
   'This page does not exist
@@ -234,10 +306,14 @@ mangler. Det er ikke muligt at redigere ligningen.',
 404',
   'This page does not have a document folder' => 'Denne side indeholder ikke en dokumentmappe',
   'This page does not have a source' => 'Denne side har ikke nogen kildetekst',
+  'This page was updated in the repository.
+Please update your working copy (Tools -> SVN update).' => '',
   'To_day|Today' => '_I dag|Gå til i dags dato',
+  'Toggle Checkbox \'V\'|Toggle checkbox' => '',
+  'Toggle Checkbox \'X\'|Toggle checkbox' => '',
   'Underline' => 'Understreg',
   'Updating links' => 'Opdaterer henvisninger',
-  'Updating links in {name}' => 'Opdaterer henvisninger i "{name}"',
+  'Updating links in {name}' => 'Opdaterer henvisninger i {name}',
   'Updating..' => 'Opdaterer...',
   'Use "Backspace" to un-indent' => 'Brug tilbage-tasten til at fjerne indrykning',
   'Use "Ctrl-Space" to switch focus' => 'Brug Ctrl-Mellemrum for at skifte fokus',
@@ -247,8 +323,11 @@ mangler. Det er ikke muligt at redigere ligningen.',
   'Use the "Backspace" key to un-indent bullet lists (Same as "Shift-Tab")' => 'Brug tilbage-tasten til at fjerne indrykningen af punktlister (samme funktion som Shift-Tab)',
   'Use the "Ctrl-Space" key combo to switch focus between text and side pane. If disabled you can still use "Alt-Space".' => 'Brug Ctrl-Mellemrum tastekombinationen for at skifte fokus imellem teksten og sidepanelet. Hvis denne er deaktiveret kan du forsat benytte Alt-Mellemrum.',
   'Use the "Enter" key to follow links. If disabled you still can use "Alt-Enter"' => 'Benyt knappen Enter til at følge en henvisning. Du kan stadig bruge Alt-Enter hvis du deaktiverer dette',
+  'User' => 'Bruger',
   'User name' => 'Brugernavn',
   'Verbatim' => 'Ordret',
+  'Versions' => 'Versioner',
+  'View _Annotated...' => 'Vis _annoteret...',
   'View _Log' => '_Vis log',
   'Web browser' => 'Webbrowser',
   'Whole _word' => '_Hele ord',
@@ -256,6 +335,8 @@ mangler. Det er ikke muligt at redigere ligningen.',
   'Word Count' => 'Ordoptælling',
   'Words' => 'Ord',
   'You can add rules to your search query below' => 'Herunder kan du tilføje regler til din søgning',
+  'You can choose using either the <b>Bazaar</b> or the <b>Subversion</b> Version Control System.
+Please click \'help\' to read about the system requirements.' => '',
   'You have no {app_type} configured' => 'Du har ikke nogen {app_type} konfigureret',
   'You need to restart the application
 for plugin changes to take effect.' => 'Du bliver nød til at genstarte programmet for at
@@ -271,11 +352,13 @@ for plugin changes to take effect.' => 'Du bliver nød til at genstarte programm
   '_Child|Go to child page' => '_Ned|Gå til siden under den nuværende',
   '_Close|Close window' => 'L_uk|Luk vinduet',
   '_Contents|Help contents' => '_Indhold|Oversigt over hjælpesiderne',
+  '_Copy Page...|Copy page' => '_Kopier side...|Kopier side',
   '_Copy|Copy' => 'Kop_iér|Kopiér teksten til udklipsholderen',
   '_Date and Time...|Insert date' => '_Dato og tid...|Indsæt tid og dato',
   '_Delete Page|Delete page' => '_Slet side|Slet den aktive side',
   '_Delete|Delete' => '_Slet|Slet tekst eller elementer',
   '_Discard changes' => 'For_kast ændringer',
+  '_Edit' => '',
   '_Edit Equation' => '_Redigér ligning',
   '_Edit Link' => '_Redigér henvisning',
   '_Edit Link...|Edit link' => '_Redigér henvisning...|Redigér en eksisterende henvisning',
@@ -305,10 +388,12 @@ for plugin changes to take effect.' => 'Du bliver nød til at genstarte programm
   '_Next' => '_Næste',
   '_Next in index|Go to next page' => 'N_æste i indeks|Gå til den næste side i indekset',
   '_Normal|Normal' => '_Normal|Normal brødtekst uden nogen speciel fremhævning',
+  '_Notebook Changes...' => 'Notesblok ændringer...',
   '_Open Another Notebook...|Open notebook' => '_Åben notesblok...|Åben en anden notesblok',
   '_Open link' => '_Åben henvisning',
   '_Overwrite' => '_Overskriv',
   '_Page' => '_Side',
+  '_Page Changes...' => '_Side ændringer',
   '_Parent|Go to parent page' => '_Op|Gå til den ovenliggende side',
   '_Paste|Paste' => 'Sæ_t ind|Indsæt teksten fra udklipsholderen',
   '_Preview' => '_Eksempel',
@@ -324,6 +409,7 @@ for plugin changes to take effect.' => 'Du bliver nød til at genstarte programm
   '_Replace' => '_Erstat',
   '_Replace...|Find and Replace' => '_Erstat...|Søg og erstat',
   '_Reset' => '_Nulstil',
+  '_Restore Version...' => '_Genopret version...',
   '_Save Copy' => '_Gem kopi',
   '_Save a copy...' => '_Gem en kopi...',
   '_Save|Save page' => '_Gem|Gem siden',
@@ -339,15 +425,22 @@ for plugin changes to take effect.' => 'Du bliver nød til at genstarte programm
   '_Underline|Underline' => '_Understreget|Understreget tekst',
   '_Undo|Undo' => '_Genskab|Fortryd den seneste ændring',
   '_Update links in this page' => 'Opdatér _henvisninger på denne side',
-  '_Update {number} pages linking here' => 'Opdatér {number} _sider der henviser hertil',
+  '_Update {number} page linking here' => [
+    'Opdatér {number} _side der henviser hertil',
+    'Opdatér {number} _sider der henviser hertil'
+  ],
   '_Verbatim|Verbatim' => '_Ordret|Tekst hvor alle bogstaver og tegn har samme bredde',
+  '_Versions...|Versions' => 'Versioner...|Versioner',
   '_View|' => '_Vis|Indstillinger for hvilke objekter du ønsker vist i Zim samt kalender og opgaveliste',
   '_Word Count|Word count' => '_Tæl ord|Tæl antallet af ord, linjer og tegn',
   'other...' => 'Anden...',
-  'translator-credits' => 'Launchpad Contributions:
-  Frederik \'Freso\' S. Olesen https://launchpad.net/~freso
-  Jeppe Toustrup https://launchpad.net/~tenzer',
   '{name}_(Copy)' => '{name}_(Kopi)',
-  '{number} _Back links' => '_Referencer: {number}',
-  '{total} items total' => '{total} opgaver i alt'
+  '{number} _Back link' => [
+    '{number} _reference',
+    '{number} _referencer'
+  ],
+  '{number} item total' => [
+    '{number} opgave i alt',
+    '{number} opgaver i alt'
+  ]
 };
